@@ -1,9 +1,9 @@
 ;;; amixer.el --- Control AMixer from Emacs
-;;;$Id: amixer.el 9336 2014-08-18 01:26:04Z tv.raman.tv $
+;;;$Id$
 ;;;Emacs front-end to AMixer
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2011, T. V. Raman<raman@cs.cornell.edu>
+;;; Copyright (C) 1995 -- 2015, T. V. Raman<raman@cs.cornell.edu>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -27,7 +27,7 @@
 
 ;;; Commentary:
 ;;; Provide an emacs front-end to amixer.
-;;;amixer is part of ALSA
+;;;amixer is part of ALSA.
 
 ;;; Code:
 
@@ -192,13 +192,31 @@
            values))
         (forward-line 1))
       (nreverse values))))
+(defvar amixer-alsactl-config-file
+  nil
+  "Personal sound card settings.
+Copied from /var/lib/alsa/asound.state to your ~/.emacs.d to avoid needing to run alsactl as root on first use.")
 
+
+(defun amixer-alsactl-setup ()
+  "Set up alsactl sound state."
+  (declare (special amixer-alsactl-config-file))
+  (setq
+   amixer-alsactl-config-file
+   (let ((sys-alsa "/var/lib/alsa/asound.state")
+         (f (expand-file-name "asound.state" user-emacs-directory)))
+     (unless (file-exists-p sys-alsa) (error "Alsa not setup correctly."))
+     (unless  (file-exists-p f) (copy-file sys-alsa user-emacs-directory))
+     f)))
+           
 ;;;###autoload
 (defun amixer (&optional refresh)
   "Interactively manipulate ALSA settings.
 Interactive prefix arg refreshes cache."
   (interactive "P")
-  (declare (special amixer-db))
+  (declare (special amixer-db
+                    amixer-alsactl-config-file))
+  (unless amixer-alsactl-config-file (amixer-alsactl-setup))
   (when (or refresh
             (null amixer-db))
     (amixer-build-db))
@@ -214,8 +232,12 @@ Interactive prefix arg refreshes cache."
         (choices nil))
     (cond
      ((null control)
-      (shell-command "alsactl restore")
-      (message "Resetting  sound to default")
+      (shell-command
+       (format "alsactl %s  restore"
+               (if amixer-alsactl-config-file
+                   (format "-f %s" amixer-alsactl-config-file)
+                 ""))
+       (message "Resetting  sound to default"))
       (amixer-build-db))
      (t
       (when (string=
