@@ -1,5 +1,5 @@
 ;;; dectalk-voices.el --- Define various device independent voices in terms of Dectalk codes.
-;;; $Id: dectalk-voices.el 8146 2013-02-09 20:05:08Z tv.raman.tv $
+;;; $Id$
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Module to set up Dectalk voices and personalities
 ;;; Keywords: Voice, Personality, Dectalk
@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2011, T. V. Raman
+;;;Copyright (C) 1995 -- 2015, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -51,9 +51,11 @@
 (require 'cl)
 (declaim  (optimize  (safety 0) (speed 3)))
 (require 'acss-structure)
+(require 'tts)
 
 ;;}}}
 ;;{{{  Top-level TTS  switcher
+
 ;;;### autoload
 (defun dectalk ()
   "Select Dectalk TTS server."
@@ -637,6 +639,25 @@ and TABLE gives the values along that dimension."
   (setq-default dtk-speech-rate-step 50
                 dtk-speech-rate-base 150))
 
+;;}}}
+;;{{{  tts-env for Dectalk:
+
+;;;###autoload
+(defun dectalk-make-tts-env  ()
+  "Constructs a TTS environment for Dectalk."
+  (declare (special dectalk-default-speech-rate  ))
+  (make-tts-env
+   :name :dectalk
+   :default-voice 'paul
+   :default-speech-rate dectalk-default-speech-rate
+   :list-voices #'dectalk-list-voices
+   :acss-voice-defined-p #'dectalk-voice-defined-p
+   :get-acss-voice-command #'dectalk-get-voice-command
+   :define-voice-from-acss #'dectalk-define-voice-from-speech-style
+   :speech-rate-base 150 :speech-rate-step 50))
+
+(tts-env-set :dectalk  (dectalk-make-tts-env))
+
 ;;}}}
 (provide 'dectalk-voices)
 ;;{{{  emacs local variables
