@@ -1,5 +1,5 @@
 ;;; emacspeak-advice.el --- Advice all core Emacs functionality to speak
-;;; $Id: emacspeak-advice.el 9509 2014-10-28 19:18:11Z tv.raman.tv $
+;;; $Id$
 ;;; $Author: tv.raman.tv $
 ;;; Description: Core advice forms that make emacspeak work
 ;;; Keywords: Emacspeak, Speech, Advice, Spoken output
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{ Copyright:
 
-;;;Copyright (C) 1995 -- 2011, T. V. Raman
+;;;Copyright (C) 1995 -- 2015, T. V. Raman
 ;;; Copyright (c) 1995, 1996, 1997 by T. V. Raman
 ;;; All Rights Reserved.
 ;;;
@@ -59,7 +59,7 @@
 ;;;Emacspeak should not be run on versions of Emacs older than
 ;;;Emacs 21,
 ;;; And preferably only run on Emacs 22.
-;;; This version of Emacspeak is only tested on Emacs 22.
+;;; This version of Emacspeak is only tested on Emacs 24 and later.
 
 ;;
 ;;; Code:
@@ -76,6 +76,7 @@
 (require 'emacspeak-speak)
 (require 'emacspeak-sounds)
 (require 'ansi-color)
+(eval-when-compile (require 'which-func))
 ;;}}}
 ;;{{{ Forward Declarations:
 (defvar emacspeak-prefix)
@@ -160,7 +161,8 @@
        (emacspeak-speak-mode-line)))))
 (loop
  for f in
- '(beginning-of-buffer end-of-buffer
+ '(
+   beginning-of-buffer end-of-buffer
                        beginning-of-defun end-of-defun)
  do
  (eval
@@ -169,6 +171,7 @@
      (when (ems-interactive-p )
        (emacspeak-auditory-icon 'large-movement)
        (emacspeak-speak-line )))))
+
 (loop
  for f in
  '(tab-to-tab-stop indent-for-tab-command reindent-then-newline-and-indent
@@ -227,19 +230,13 @@
                 up-list backward-up-list down-list)
  do
  (eval
-  `(defadvice ,f (around emacspeak pre act comp)
-     "Speak the list.
-If you moved more than a line,
- only speak the target line."
-     (if (ems-interactive-p )
-         (let ((start (point)))
-           ad-do-it
-           (cond
-            ((ems-same-line-p start (point))
-             (emacspeak-speak-region start (point )))
-            (t (emacspeak-speak-line))))
-       ad-do-it)
-     ad-return-value)))
+  `(defadvice ,f (after emacspeak pre act comp)
+     "Speak line."
+     (when (ems-interactive-p)
+       (emacspeak-auditory-icon 'large-movement)
+       (let ((emacspeak-show-point t))
+         (emacspeak-speak-line))))))
+
 (loop
  for f in
  '(forward-page backward-page)
@@ -379,6 +376,7 @@ the words that were capitalized."
        ad-do-it)
       (t ad-do-it))
      ad-return-value)))
+
 (loop
  for f in
  '(delete-forward-char delete-char)
@@ -450,7 +448,7 @@ the words that were capitalized."
     (let (thisblank singleblank)
       (save-match-data
         (save-excursion
-          (beginning-of-line)
+          (forward-line 0)
           (setq thisblank (looking-at "[ \t]*$"))
           ;; Set singleblank if there is just one blank line here.
           (setq singleblank
@@ -495,7 +493,7 @@ see option emacspeak-untabify-fixes-non-breaking-space."
   "Provide auditory feedback."
   (when (ems-interactive-p )
     (emacspeak-auditory-icon 'help)
-    (emacspeak-auditory-icon 'help)))
+    (emacspeak-auditory-icon 'complete)))
 
 (defadvice pcomplete-show-completions (around emacspeak pre act comp)
   (let ((emacspeak-speak-messages nil))
@@ -552,7 +550,6 @@ see option emacspeak-untabify-fixes-non-breaking-space."
   (when (ems-interactive-p )
     (emacspeak-speak-this-char (preceding-char ))))
 
-;;;###autoload
 (defvar emacspeak-speak-read-events t
   "Set to nil to silence read-event.")
 
@@ -565,6 +562,7 @@ see option emacspeak-untabify-fixes-non-breaking-space."
  for f in
  '(
    next-history-element previous-history-element
+                        next-line-or-history-element previous-line-or-history-element
                         previous-matching-history-element next-matching-history-element)
  do
  (eval
@@ -583,9 +581,9 @@ see option emacspeak-untabify-fixes-non-breaking-space."
 
 (defadvice momentary-string-display (around emacspeak pre act comp)
   "Provide spoken feedback."
-  (let ((emacspeak-speak-messages nil)
-        (msg (ad-get-arg 0))
-        (exit (ad-get-arg 2)))
+  (lexical-let ((emacspeak-speak-messages nil)
+                (msg (ad-get-arg 0))
+                (exit (ad-get-arg 2)))
     (dtk-speak
      (format "%s %s"
              msg
@@ -603,32 +601,38 @@ icon."
 
 (defadvice progress-reporter-do-update (around emacspeak pre act comp)
   "Silence progress reporters for now."
-  (let ((emacspeak-speak-messages nil))
+  (lexical-let ((emacspeak-speak-messages nil))
     (when emacspeak-advice-progress-reporter
       (emacspeak-auditory-icon 'progress))
     ad-do-it))
+;;; forward decl:
 
+(unless (boundp 'inhibit-message)(defvar inhibit-message nil)
+        (defvar inhibit-message nil
+          "In Emacs 25, this  will  inhibit messages in echo area. "))
 (defadvice message (around emacspeak pre act comp)
   "Speak the message."
-  (declare (special emacspeak-last-message
+  (declare (special emacspeak-last-message inhibit-message
                     emacspeak-speak-messages emacspeak-lazy-message-time))
   (let ((inhibit-read-only t))
     ad-do-it
-    (when (and
-           (current-message)
-           emacspeak-speak-messages ; speaking messages
-           (/= emacspeak-lazy-message-time ;; previous message not recent
-               (setq emacspeak-lazy-message-time (nth 1 (current-time)))))
+    (when
+        (and
+         emacspeak-speak-messages          ; speaking messages
+         (null inhibit-message)
+         (current-message)
+         (/= emacspeak-lazy-message-time ;; previous message not recent
+             (setq emacspeak-lazy-message-time (nth 1 (current-time)))))
       (setq emacspeak-last-message (ansi-color-apply (current-message)))
       ;; so we really need to speak it
       (tts-with-punctuations 'all
-                             (dtk-speak emacspeak-last-message)))
+                             (dtk-notify-using-voice voice-annotate  emacspeak-last-message)))
     ad-return-value))
 
 (defadvice eldoc-message (around emacspeak pre act comp)
   "Speech enable ELDoc --- now used by semantic."
  ;;; eldoc flashes message temporarily, we cache and speak.
-  (let ((emacspeak-speak-messages nil))
+  (lexical-let ((emacspeak-speak-messages nil))
     ad-do-it
     (when eldoc-last-message
       (dtk-speak-and-echo eldoc-last-message))
@@ -641,7 +645,7 @@ icon."
   "Jibber intelligently."
   (declare (special emacspeak-ange-ftp-last-percent
                     ange-ftp-last-percent ))
-  (let ((emacspeak-speak-messages nil ))
+  (lexical-let ((emacspeak-speak-messages nil ))
     ad-do-it
     (when (or
            (null emacspeak-ange-ftp-last-percent)
@@ -692,8 +696,7 @@ icon."
 ;;; Silence messages from async handlers:
 (defadvice timer-event-handler (around emacspeak pre act comp)
   "Silence messages generated by timer event handlers."
-  (declare (special emacspeak-speak-messages))
-  (let ((emacspeak-speak-messages nil))
+  (lexical-let ((emacspeak-speak-messages nil))
     ad-do-it))
 
 ;;}}}
@@ -739,7 +742,7 @@ Produce an auditory icon if possible."
 
 (defadvice read-char-choice(before emacspeak pre act comp)
   "Speak the prompt"
-  (let ((prommmmpt (ad-get-arg 0))
+  (let ((prompt (ad-get-arg 0))
         (chars (ad-get-arg 1)))
     (tts-with-punctuations
      'all
@@ -769,62 +772,69 @@ Produce an auditory icon if possible."
    (completions-annotations voice-annotate)
    (completions-common-part voice-monotone)
    (completions-first-difference voice-brighten)))
-(loop for f in
-      '(minibuffer-complete-word minibuffer-complete)
-      do
-      (eval
-       `(defadvice ,f (around emacspeak pre act comp)
-          "Say what you completed."
-          (cond
-           ((ems-interactive-p )
-            (let ((prior (point ))
-                  (emacspeak-speak-messages nil))
-              (emacspeak-kill-buffer-carefully "*Completions*")
-              ad-do-it
-              (if (> (point) prior)
-                  (tts-with-punctuations
-                   'all
-                   (dtk-speak
-                    (buffer-substring (point) prior)))
-                (emacspeak-speak-completions-if-available))))
-           (t ad-do-it))
-          ad-return-value)))
+(loop
+ for f in
+ '(minibuffer-complete-word minibuffer-complete
+                            crm-complete-word crm-complete crm-complete-and-exit
+                            crm-minibuffer-complete crm-minibuffer-complete-and-exit)
+ do
+ (eval
+  `(defadvice ,f (around emacspeak pre act comp)
+     "Say what you completed."
+     (cond
+      ((ems-interactive-p )
+       (let ((prior (point ))
+             (emacspeak-speak-messages nil))
+         (emacspeak-kill-buffer-carefully "*Completions*")
+         ad-do-it
+         (if (> (point) prior)
+             (tts-with-punctuations
+              'all
+              (dtk-speak
+               (buffer-substring (point) prior)))
+           (emacspeak-speak-completions-if-available))))
+      (t ad-do-it))
+     ad-return-value)))
 
-(loop for f in
-      '(lisp-complete-symbol complete-symbol
-                             widget-complete)
-      do
-      (eval
-       `(defadvice ,f (around emacspeak pre act comp)
-          "Say what you completed."
-          (let ((prior (point ))
-                (emacspeak-speak-messages nil))
-            ad-do-it
-            (if (> (point) prior)
-                (tts-with-punctuations
-                 'all
-                 (dtk-speak
-                  (buffer-substring prior (point))))
-              (emacspeak-speak-completions-if-available))
-            ad-return-value))))
+(loop
+ for f in
+ '(lisp-complete-symbol complete-symbol widget-complete)
+ do
+ (eval
+  `(defadvice ,f (around emacspeak pre act comp)
+     "Say what you completed."
+     (let ((prior (point ))
+           (emacspeak-speak-messages nil))
+       ad-do-it
+       (if (> (point) prior)
+           (tts-with-punctuations
+            'all
+            (dtk-speak
+             (buffer-substring prior (point))))
+         (emacspeak-speak-completions-if-available))
+       ad-return-value))))
 (define-key minibuffer-local-completion-map "\C-o" 'switch-to-completions)
 (defadvice switch-to-completions(after emacspeak pre act comp)
   "Provide spoken feedback."
   (emacspeak-auditory-icon 'select-object)
   (dtk-speak (emacspeak-get-current-completion)))
-
-(defadvice complete (around emacspeak pre act comp)
-  "Say what you completed."
-  (let ((emacspeak-speak-messages nil)
-        (emacspeak-last-message nil))
-    ad-do-it
-    (when (ems-interactive-p )
-      (dtk-speak
-       (format "%s %s"
-               (save-excursion (backward-char 1)
-                               (sexp-at-point ))
-               (or emacspeak-last-message "")))
-      ad-return-value)))
+(loop
+ for f in
+ '(complete )
+ do
+ (eval
+  `(defadvice ,f  (around emacspeak pre act comp)
+     "Say what you completed."
+     (lexical-let ((emacspeak-speak-messages nil)
+                   (emacspeak-last-message nil))
+       ad-do-it
+       (when (ems-interactive-p )
+         (dtk-speak
+          (format "%s %s"
+                  (save-excursion (backward-char 1)
+                                  (sexp-at-point ))
+                  (or emacspeak-last-message "")))
+         ad-return-value)))))
 
 (defadvice minibuffer-complete-shell-command (around emacspeak pre act comp)
   "Say what you completed."
@@ -887,7 +897,7 @@ Produce an auditory icon if possible."
 (defadvice minibuffer-complete-and-exit (before emacspeak pre act comp)
   "Provide an auditory icon."
   (when (ems-interactive-p )
-    (emacspeak-auditory-icon 'button)))
+    (emacspeak-auditory-icon 'close-object)))
 
 (defadvice tmm-menubar (before emacspeak pre act comp)
   "Provide an auditory icon."
@@ -900,6 +910,11 @@ Produce an auditory icon if possible."
 
 ;;}}}
 ;;{{{ Advice comint:
+(defadvice comint-clear-buffer (after emacspeak pre act comp)
+  "Provide auditory feedback."
+  (when (ems-interactive-p)
+    (emacspeak-auditory-icon 'delete-object)
+    (emacspeak-speak-line)))
 
 (defadvice comint-magic-space (around emacspeak pre act comp)
   "Speak word or completion."
@@ -946,8 +961,8 @@ Produce an auditory icon if possible."
 (add-hook 'comint-output-filter-functions 'comint-watch-for-password-prompt )
 (voice-setup-add-map
  '(
-   (comint-highlight-prompt voice-monotone-medium)
-   (comint-highlight-input voice-bolden-medium)))
+   (comint-highlight-prompt voice-monotone)
+   (comint-highlight-input voice-bolden)))
 (declaim (special emacspeak-pronounce-sha-checksum-pattern))
 
 (emacspeak-pronounce-add-dictionary-entry
@@ -956,19 +971,30 @@ Produce an auditory icon if possible."
  (cons 're-search-forward
        'emacspeak-pronounce-sha-checksum))
 
+(declaim (special emacspeak-pronounce-uuid-pattern))
+
+(emacspeak-pronounce-add-dictionary-entry
+ 'comint-mode
+ emacspeak-pronounce-uuid-pattern
+ (cons 're-search-forward
+       'emacspeak-pronounce-uuid))
+(loop
+ for mode in
+ '(conf-space-mode conf-unix-mode conf-mode)
+ do
+ (emacspeak-pronounce-add-dictionary-entry
+  mode
+  emacspeak-pronounce-uuid-pattern
+  (cons 're-search-forward
+        'emacspeak-pronounce-uuid)))
+
 (add-hook 'shell-mode-hook 'emacspeak-pronounce-refresh-pronunciations)
 
-(loop for f in
-      '(shell-command shell-dirstack-message)
-      do
-      (eval
-       `(defadvice ,f (around emacspeak pre act comp)
-          "Silence messages"
-          (cond
-           ((ems-interactive-p )
-            ad-do-it)
-           (t (let ((emacspeak-speak-messages nil))
-                ad-do-it))))))
+
+(defadvice shell-dirstack-message (around emacspeak pre act comp)
+     "Silence messages"
+     (ems-with-messages-silenced
+      ad-do-it))
 
 (add-hook 'comint-mode-hook 'emacspeak-comint-speech-setup)
 
@@ -985,13 +1011,6 @@ Produce an auditory icon if possible."
    (t ad-do-it))
   ad-return-value)
 
-(defadvice comint-send-input (before emacspeak pre act comp)
-  "Aurally highlight input."
-  (let ((start (line-beginning-position))
-        (end (line-end-position)))
-    (emacspeak-personality-append start end
-                                  'emacspeak-comint-input-personality)))
-
 (defadvice comint-send-eof (before emacspeak pre act comp)
   "Announce what we are doing."
   (when (ems-interactive-p )
@@ -1092,7 +1111,7 @@ Produce an auditory icon if possible."
           'rear-sticky nil)))
       (when (and
              comint-last-output-start
-             emacspeak-comint-autospeak 
+             emacspeak-comint-autospeak
              (or monitor (eq (window-buffer) buffer)))
         (emacspeak-speak-region comint-last-output-start (point )))
       ad-return-value)))
@@ -1264,13 +1283,19 @@ process PID's current working directory.
 
 Turning on Ditrack-Procfs mode automatically turns off
 Shell-Dirtrack mode; turning it off does not re-enable it."
-  nil "DirTrack" nil 
+  nil "DirTrack" nil
   (if (not dirtrack-procfs-mode)
       (remove-hook 'comint-preoutput-filter-functions #'emacspeak-shell-dirtrack-procfs t)
     (add-hook 'comint-preoutput-filter-functions #'emacspeak-shell-dirtrack-procfs nil t)
     (shell-dirtrack-mode 0)))
 (when (file-exists-p "/proc")
   (add-hook 'shell-mode-hook 'dirtrack-procfs-mode))
+
+;;; Silence Bash completions chatter:
+(defadvice bash-completion-dynamic-complete-0 (around emacspeak pre act comp)
+  "Silence chatter."
+  (ems-with-messages-silenced ad-do-it))
+
 ;;}}}
 ;;{{{ Advice centering and filling commands:
 
@@ -1370,17 +1395,18 @@ Shell-Dirtrack mode; turning it off does not re-enable it."
     (message "Checked in version %s "
              (emacspeak-vc-get-version-id))))
 
-(loop for f in
-      '(vc-dir-next-line vc-dir-previous-line
-                         vc-dir-next-directory vc-dir-previous-directory
-                         )
-      do
-      (eval
-       `(defadvice ,f (after emacspeak-pre act comp)
-          "Provide auditory feedback."
-          (when (ems-interactive-p )
-            (emacspeak-speak-line)
-            (emacspeak-auditory-icon 'select-object)))))
+(loop
+ for f in
+ '(vc-dir-next-line vc-dir-previous-line
+                    vc-dir-next-directory vc-dir-previous-directory
+                    )
+ do
+ (eval
+  `(defadvice ,f (after emacspeak-pre act comp)
+     "Provide auditory feedback."
+     (when (ems-interactive-p )
+       (emacspeak-speak-line)
+       (emacspeak-auditory-icon 'select-object)))))
 
 (defadvice vc-dir-mark-file (after emacspeak-pre act comp)
   "Provide auditory feedback."
@@ -1415,25 +1441,27 @@ Shell-Dirtrack mode; turning it off does not re-enable it."
 ;;}}}
 ;;{{{ composing mail
 
-(loop for f in
-      '(mail mail-other-window mail-other-frame )
-      do
-      (eval
-       `(defadvice ,f (after emacspeak pre act comp)
-          "Give some auditory feedback."
-          (emacspeak-auditory-icon 'open-object)
-          (save-excursion
-            (goto-char (point-min))
-            (emacspeak-speak-line)))))
-(loop for f in
-      '(mail-text mail-subject mail-cc mail-bcc
-                  mail-to mail-reply-to mail-fcc)
-      do
-      (eval
-       `(defadvice ,f (after emacspeak pre act comp)
-          "Speak the reply-to line."
-          (when (ems-interactive-p )
-            (emacspeak-speak-line )))))
+(loop
+ for f in
+ '(mail mail-other-window mail-other-frame )
+ do
+ (eval
+  `(defadvice ,f (after emacspeak pre act comp)
+     "Give some auditory feedback."
+     (emacspeak-auditory-icon 'open-object)
+     (save-excursion
+       (goto-char (point-min))
+       (emacspeak-speak-line)))))
+(loop
+ for f in
+ '(mail-text mail-subject mail-cc mail-bcc
+             mail-to mail-reply-to mail-fcc)
+ do
+ (eval
+  `(defadvice ,f (after emacspeak pre act comp)
+     "Speak the reply-to line."
+     (when (ems-interactive-p )
+       (emacspeak-speak-line )))))
 
 (defadvice mail-signature (after emacspeak pre act comp)
   "Announce you signed the message."
@@ -1460,16 +1488,16 @@ Shell-Dirtrack mode; turning it off does not re-enable it."
   (when (ems-interactive-p )
     (message "Displayed mode help in help window")
     (emacspeak-auditory-icon 'help)))
-(loop for f in
-      '(describe-bindings
-        describe-prefix-bindings)
-      do
-      (eval
-       `(defadvice ,f (after emacspeak pre act comp)
-          "Provide auditory feedback."
-          (when (ems-interactive-p )
-            (message "Displayed key bindings in help window")
-            (emacspeak-auditory-icon 'help)))))
+(loop
+ for f in
+ '(describe-bindings describe-prefix-bindings)
+ do
+ (eval
+  `(defadvice ,f (after emacspeak pre act comp)
+     "Provide auditory feedback."
+     (when (ems-interactive-p )
+       (message "Displayed key bindings in help window")
+       (emacspeak-auditory-icon 'help)))))
 
 (defadvice line-number-mode (after emacspeak pre act comp)
   "Provide auditory feedback."
@@ -1541,8 +1569,7 @@ Produce an auditory icon if possible."
     (emacspeak-speak-mode-line)))
 (loop
  for f in
- '(kill-buffer delete-frame quit-window
-               delete-other-windows delete-other-frames)
+ '(kill-buffer  quit-window)
  do
  (eval
   `(defadvice ,f (after emacspeak pre act comp)
@@ -1550,10 +1577,24 @@ Produce an auditory icon if possible."
      (when (ems-interactive-p )
        (emacspeak-auditory-icon 'close-object)
        (emacspeak-speak-mode-line)))))
+
 (loop
  for f in
- '(
-   other-frame other-window
+ '(delete-windows-on delete-other-frames
+                     delete-window delete-completion-window
+                     split-window-below split-window-right
+                     split-window-vertically split-window-horizontally)
+ do
+ (eval
+  `(defadvice ,f (after emacspeak pre act comp)
+     "Speech-enabled by emacspeak."
+     (when (ems-interactive-p )
+       (emacspeak-auditory-icon 'window-resize)
+       (emacspeak-speak-mode-line)))))
+
+(loop
+ for f in
+ '(other-frame other-window
                switch-to-prev-buffer switch-to-next-buffer
                switch-to-buffer switch-to-buffer-other-window switch-to-buffer-other-frame)
  do
@@ -1610,19 +1651,21 @@ Indicate change of selection with an auditory icon
     (emacspeak-speak-line)
     (emacspeak-auditory-icon 'button)))
 
-;;; Silence help for help 
+;;; Silence help for help
 (defadvice help-window-display-message (around emacspeak pre act comp)
-  (let ((emacspeak-speak-messages  nil))
-    ad-do-it))
+  (ems-with-messages-silenced ad-do-it))
 
 (loop
  for f in
- '(describe-function describe-variable describe-key)
+ '(
+   describe-function describe-variable
+   describe-face describe-font
+   describe-package describe-key)
  do
  (eval
   `(defadvice ,f (after emacspeak pre act comp)
      "Speak the help."
-     (when t ;(ems-interactive-p )
+     (when  (ems-interactive-p )
        (emacspeak-auditory-icon 'help)
        (emacspeak-speak-help )))))
 
@@ -1645,7 +1688,7 @@ Indicate change of selection with an auditory icon
         (alt-regexp "C-x @ a")
         (super-regexp "C-x @ s"))
     (condition-case nil
-        (with-temp-buffer 
+        (with-temp-buffer
           (setq buffer-undo-list t)
           (setq case-fold-search nil)
           (erase-buffer)
@@ -1697,7 +1740,7 @@ Auditory highlight indicates position of point."
       (emacspeak-speak-line))))
 (loop
  for f in
- '(newline newline-and-indent)
+ '(newline newline-and-indent electric-newline-and-maybe-indent)
  do
  (eval
   `(defadvice ,f (before emacspeak pre act comp)
@@ -1709,7 +1752,8 @@ the newly created blank line."
        (cond
         (emacspeak-line-echo (emacspeak-speak-line ))
         (t(when dtk-stop-immediately (dtk-stop))
-          (dtk-tone 225 120 'force )))))))
+          (dtk-tone 225 75 'force )))))))
+
 (loop
  for f in
  '(keyboard-quit keyboard-escape-quit)
@@ -1728,7 +1772,7 @@ the newly created blank line."
  (eval
   `(defadvice ,f (after emacspeak pre act comp)
      "Also speaks the result of evaluation."
-     (when t ;(ems-interactive-p)
+     (when (ems-interactive-p)
        (let ((dtk-chunk-separator-syntax " .<>()$\"\'"))
          (tts-with-punctuations 'all
                                 (dtk-speak
@@ -1756,9 +1800,9 @@ Provide an auditory icon if possible."
   "Provide spoken feedback."
   (cond
    ((ems-interactive-p )
-    (let ((dtk-quiet t)
-          (emacspeak-speak-messages nil)
-          (emacspeak-use-auditory-icons nil))
+    (lexical-let ((dtk-quiet t)
+                  (emacspeak-speak-messages nil)
+                  (emacspeak-use-auditory-icons nil))
       ad-do-it)
     (message "Executed macro. ")
     (emacspeak-auditory-icon 'task-done))
@@ -1805,17 +1849,18 @@ Provide an auditory icon if possible."
     (message "Upcased region containing %s lines"
              (count-lines (region-beginning)
                           (region-end)))))
-(loop for f in
-      '(narrow-to-region narrow-to-page)
-      do
-      (eval
-       `(defadvice ,f (after emacspeak pre act comp)
-          "Announce yourself."
-          (when (ems-interactive-p )
-            (emacspeak-auditory-icon 'select-object)
-            (message "Narrowed editing region to %s lines"
-                     (count-lines (region-beginning)
-                                  (region-end)))))))
+(loop
+ for f in
+ '(narrow-to-region narrow-to-page)
+ do
+ (eval
+  `(defadvice ,f (after emacspeak pre act comp)
+     "Announce yourself."
+     (when (ems-interactive-p )
+       (emacspeak-auditory-icon 'select-object)
+       (message "Narrowed editing region to %s lines"
+                (count-lines (region-beginning)
+                             (region-end)))))))
 
 (defadvice narrow-to-defun (after emacspeak pre act comp)
   "Announce yourself."
@@ -1834,6 +1879,7 @@ Provide an auditory icon if possible."
   "Provide spoken feedback."
   (when (ems-interactive-p )
     (message "Deleted all other windows")
+    (emacspeak-auditory-icon 'window-resize)
     (emacspeak-speak-mode-line)))
 
 (defadvice split-window-vertically (after emacspeak pre act comp)
@@ -1911,18 +1957,19 @@ Provide an auditory icon if possible."
   "Provide auditory feedback."
   (when (ems-interactive-p )
     (message "Aborting recursive edit")))
-(loop for f in
-      '(undo undo-only)
-      do
-      (eval
-       `(defadvice ,f (after emacspeak pre act comp)
-          "Provide auditory feedback."
-          (when (ems-interactive-p )
-            (let ((emacspeak-show-point t))
-              (emacspeak-speak-line ))
-            (if (buffer-modified-p)
-                (emacspeak-auditory-icon 'modified-object)
-              (emacspeak-auditory-icon 'unmodified-object ))))))
+(loop
+ for f in
+ '(undo undo-only)
+ do
+ (eval
+  `(defadvice ,f (after emacspeak pre act comp)
+     "Provide auditory feedback."
+     (when (ems-interactive-p )
+       (let ((emacspeak-show-point t))
+         (emacspeak-speak-line ))
+       (if (buffer-modified-p)
+           (emacspeak-auditory-icon 'modified-object)
+         (emacspeak-auditory-icon 'unmodified-object ))))))
 
 (defadvice view-emacs-news (after emacspeak pre act comp)
   "Provide auditory cue."
@@ -1953,19 +2000,29 @@ Provide an auditory icon if possible."
           (dtk-speak msg)
         (emacspeak-auditory-icon 'close-object)))))
 
-(loop for f in
-      '(tooltip-show-help-non-mode tooltip-sho)
-      do
-      (eval
-       `(defadvice ,f (after emacspeak pre act comp)
-          "Speak the tooltip."
-          (when emacspeak-speak-tooltips
-            (let ((help (ad-get-arg 0)))
-              (dtk-speak help)
-              (emacspeak-auditory-icon 'help))))))
+(loop
+ for f in
+ '(tooltip-show-help-non-mode tooltip-sho)
+ do
+ (eval
+  `(defadvice ,f (after emacspeak pre act comp)
+     "Speak the tooltip."
+     (when emacspeak-speak-tooltips
+       (let ((help (ad-get-arg 0)))
+         (dtk-speak help)
+         (emacspeak-auditory-icon 'help))))))
 
 ;;}}}
 ;;{{{ Emacs server
+(defun emacspeak-speak-announce-server-buffer ()
+  "Announce opening of an emacsclient buffer."
+  (emacspeak-speak-mode-line)
+  (emacspeak-auditory-icon 'open-object))
+(add-hook 'server-done-hook
+          #'(lambda nil
+              (emacspeak-auditory-icon 'close-object)))
+
+(add-hook 'server-switch-hook 'emacspeak-speak-announce-server-buffer)
 
 (defadvice server-start (after emacspeak pre act comp)
   "Provide auditory confirmation."
@@ -2004,7 +2061,7 @@ Provide an auditory icon if possible."
 Produce an auditory icon if possible."
   (cond
    ((ems-interactive-p )
-    (let ((emacspeak-speak-messages nil))
+    (lexical-let ((emacspeak-speak-messages nil))
       (dtk-speak "Byte compiling ")
       ad-do-it
       (emacspeak-auditory-icon 'task-done)
@@ -2066,49 +2123,41 @@ Produce an auditory icon if possible."
 (declaim (special isearch-mode-map
                   minibuffer-local-isearch-map emacspeak-prefix))
 
-(define-key
-  minibuffer-local-isearch-map emacspeak-prefix 'emacspeak-prefix-command)
+(define-key minibuffer-local-isearch-map
+  emacspeak-prefix 'emacspeak-prefix-command)
 (define-key isearch-mode-map emacspeak-prefix 'emacspeak-prefix-command)
 (define-key isearch-mode-map "\M-m" 'isearch-exit)
 ;;; ISearch setup/teardown
 
-;;; temporarily silence messages,
 ;;; Produce auditory icon
-
 (defsubst emacspeak-isearch-setup()
   "Setup emacspeak environment for isearch."
-  (declare (special emacspeak-speak-messages))
   (emacspeak-auditory-icon 'open-object)
   (setq emacspeak-speak-messages nil)
   (dtk-speak "I-Search: "))
 
 (defsubst emacspeak-isearch-teardown()
   "Teardown emacspeak environment for isearch."
-  (declare (special emacspeak-speak-messages))
-  (emacspeak-auditory-icon 'close-object)
-  (setq emacspeak-speak-messages t))
+  (setq emacspeak-speak-messages t)
+  (emacspeak-auditory-icon 'close-object))
 
 (add-hook 'isearch-mode-hook 'emacspeak-isearch-setup)
 (add-hook 'isearch-mode-end-hook 'emacspeak-isearch-teardown)
+(add-hook 'isearch-mode-end-hook-quit 'emacspeak-isearch-teardown)
 
 ;;; Advice isearch-search to speak
-
 (defadvice isearch-search (after emacspeak pre act comp)
   "Speak the search hit."
-  (emacspeak-speak-string isearch-string voice-bolden)
-  (when (sit-for 0.5)
+  (cond
+   ((null isearch-success) (emacspeak-auditory-icon 'search-miss))
+   (t
     (emacspeak-auditory-icon 'search-hit)
-    (save-excursion
-      (ems-set-personality-temporarily
-       (point)
-       (if isearch-forward
-           (- (point) (length isearch-string ))
-         (+ (point) (length isearch-string )))
-       voice-bolden
-       (dtk-speak
-        (buffer-substring
-         (line-beginning-position)
-         (line-end-position)))))))
+    (when (sit-for  0.2)
+      (save-excursion
+        (ems-set-personality-temporarily
+         (point) isearch-other-end voice-bolden
+         (dtk-speak
+          (buffer-substring (line-beginning-position) (line-end-position)))))))))
 
 (defadvice isearch-delete-char (after emacspeak pre act comp)
   "Speak the search hit.
@@ -2389,7 +2438,7 @@ Produce auditory icons if possible."
 
 (defadvice where-is (after emacspeak pre act comp)
   "Provide spoken feedback"
-  (when t ;(ems-interactive-p )
+  (when (ems-interactive-p )
     (emacspeak-speak-message-again)))
 
 ;;}}}
@@ -2401,12 +2450,12 @@ Produce auditory icons if possible."
  (eval
   `(defadvice ,f (after emacspeak pre act comp)
      "Provide an auditory icon."
-     (when t ;(ems-interactive-p )
+     (when (ems-interactive-p )
        (emacspeak-auditory-icon 'help)))))
 
 (defadvice apropos-follow (after emacspeak pre act comp)
   "Speak the help you displayed."
-  (when t ;(ems-interactive-p )
+  (when (ems-interactive-p )
     (emacspeak-auditory-icon 'select-object)
     (emacspeak-speak-help)))
 
@@ -2476,17 +2525,6 @@ Produce auditory icons if possible."
 ;;}}}
 ;;{{{ provide auditory icon when window config changes
 
-(defun emacspeak-window-resize (ignore)
-  "Play window resize icon."
-  (emacspeak-auditory-icon 'window-resize))
-
-(defvar emacspeak-sounds-icon-on-window-resize nil
-  "If T then window resize will produce an auditory icon.")
-
-(when emacspeak-sounds-icon-on-window-resize
-  (add-hook 'window-size-change-functions
-            'emacspeak-window-resize))
-
 ;;}}}
 ;;{{{ advice load to speech-enable new commands
 
@@ -2515,10 +2553,10 @@ Produce auditory icons if possible."
      "Silence messages while elint is running."
      (cond
       ((ems-interactive-p )
-       (let ((emacspeak-speak-messages nil))
-         ad-do-it
-         (emacspeak-auditory-icon 'task-done)
-         (message "Displayed lint results in other window. ")))
+       (ems-with-messages-silenced
+        ad-do-it
+        (emacspeak-auditory-icon 'task-done)
+        (message "Displayed lint results in other window. ")))
       (t ad-do-it))
      ad-return-value)))
 
@@ -2532,17 +2570,19 @@ Produce auditory icons if possible."
  (eval
   `(defadvice ,f (after emacspeak pre act comp)
      "Adds property personality."
-     (let ((beg (ad-get-arg 0))
+     (let ((start (ad-get-arg 0))
            (end (ad-get-arg 1)))
        (with-silent-modifications
-         (add-text-properties
-          beg end
-          (list 'personality voice-bolden
-                'auditory-icon 'button)))))))
+         (condition-case nil
+             (progn 
+               (put-text-property start end  'auditory-icon 'button)
+               (when emacspeak-personality-voiceify-faces
+                 (put-text-property start end 'personality voice-bolden)))
+           (error nil)))))))
 
 (defadvice push-button (after emacspeak pre act comp)
   "Produce auditory icon."
-  (when  (ems-interactive-p ) 
+  (when  (ems-interactive-p )
     (emacspeak-auditory-icon 'push-button)
     (emacspeak-speak-line)))
 
@@ -2625,8 +2665,7 @@ Produce auditory icons if possible."
 ;;}}}
 ;;{{{ silence midnight cleanup:
 (defadvice clean-buffer-list(around emacspeak pre act comp)
-  (let ((emacspeak-speak-messages nil))
-    ad-do-it))
+  (ems-with-messages-silenced ad-do-it))
 
 ;;}}}
 ;;{{{ Splash Screen:
@@ -2666,11 +2705,43 @@ Produce auditory icons if possible."
     (emacspeak-auditory-icon 'task-done)))
 
 ;;}}}
-;;{{{ Managing packages:
-(defadvice package-menu-execute(around emacspeak pre act comp)
-  "Silence messages while installing packages. "
-  (let ((emacspeak-speak-messages nil))
-    ad-do-it))
+;;{{{ Asking Questions:
+
+(defadvice yes-or-no-p (before emacspeak pre act comp)
+  "Play auditory icon."
+  (emacspeak-auditory-icon 'ask-question))
+
+(defadvice yes-or-no-p (after emacspeak pre act comp)
+  "Play auditory icon."
+  (cond
+   (ad-return-value
+    (emacspeak-auditory-icon 'yes-answer))
+   (t (emacspeak-auditory-icon 'no-answer))))
+
+(defadvice ask-user-about-lock (before emacspeak pre act comp)
+  "Play auditory icon."
+  (emacspeak-auditory-icon 'ask-short-question))
+
+(defadvice ask-user-about-lock (after emacspeak pre act comp)
+  "Play auditory icon."
+  (cond
+   (ad-return-value (emacspeak-auditory-icon 'y-answer))
+   (t (emacspeak-auditory-icon 'n-answer))))
+
+(defadvice ask-user-about-lock-help (after emacspeak pre act comp)
+  "Play auditory icon."
+  (emacspeak-auditory-icon 'help))
+
+(defadvice y-or-n-p (before emacspeak pre act comp)
+  "Play auditory icon."
+  (emacspeak-auditory-icon 'ask-short-question))
+
+(defadvice y-or-n-p (after emacspeak pre act comp)
+  "Play auditory icon."
+  (cond
+   (ad-return-value (emacspeak-auditory-icon 'y-answer))
+   (t (emacspeak-auditory-icon 'n-answer))))
+
 ;;}}}
 (provide 'emacspeak-advice)
 ;;{{{ end of file
