@@ -1,5 +1,5 @@
 ;;; emacspeak-c.el --- Speech enable CC-mode and friends -- supports C, C++, Java
-;;; $Id: emacspeak-c.el 9336 2014-08-18 01:26:04Z tv.raman.tv $
+;;; $Id$
 ;;; $Author: tv.raman.tv $
 ;;; DescriptionEmacspeak extensions for C and C++ mode
 ;;; Keywords:emacspeak, audio interface to emacs C, C++
@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2011, T. V. Raman
+;;;Copyright (C) 1995 -- 2015, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -381,16 +381,16 @@ and their meanings. ")
                         ;; that begins this block
                         (let ((start nil ))
                           (save-excursion
-                            (beginning-of-line)
+                            (forward-line 0)
                             (search-forward "}" nil t)
                             (forward-char 1)
                             (backward-sexp 1)
                             (setq start (point))
-                            (beginning-of-line)
+                            (forward-line 0)
                             (skip-syntax-forward " ")
                             (and (= start (point))
                                  (forward-line -1)
-                                 (beginning-of-line))
+                                 (forward-line 0))
                             (setq start (point))
                             (end-of-line)
                             (buffer-substring start
