@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1999, 2011 T. V. Raman <raman@cs.cornell.edu>
+;;; Copyright (C) 1995 -- 2015, T. V. Raman
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -62,7 +62,7 @@
 (require 'emacspeak-webutils)
 (require 'emacspeak-xslt)
 (require 'derived)
-
+(require 'locate)
 ;;}}}
 ;;{{{  Customizations, Variables:
 
@@ -116,7 +116,8 @@
 (defsubst emacspeak-epub-do-toc (file)
   "Return location of .ncx file within epub archive."
   (declare (special emacspeak-epub-toc-command))
-  (let ((result (shell-command-to-string (format emacspeak-epub-toc-command file ))))
+  (let ((result
+         (shell-command-to-string (format emacspeak-epub-toc-command  file))))
     (cond
      ((= 0 (length result)) nil)
      (t (substring result 0 -1)))))
@@ -194,11 +195,11 @@
     buffer))
 
 (defvar emacspeak-epub-metadata-xsl
-  (expand-file-name "epub-metadata.xsl" emacspeak-xslt-directory)
+  (emacspeak-xslt-get "epub-metadata.xsl")
   "XSL to extract Author/Title information.")
 
 (defvar emacspeak-epub-opf-xsl
-  (expand-file-name "epub-opf.xsl" emacspeak-xslt-directory)
+  (emacspeak-xslt-get "epub-opf.xsl")
   "XSL to extract Author/Title information from content.opf.")
 
 (defsubst emacspeak-epub-get-metadata (epub)
@@ -218,15 +219,16 @@
   "EPub associated with current buffer.")
 
 (make-variable-buffer-local 'emacspeak-epub-this-epub)
+(declare-function w3-fetch  "w3" (url))
+(declare-function w3-download-url  "w3" (url &optional file-name))
 
 (defun emacspeak-epub-browse-content (epub element fragment &optional style )
   "Browse content in specified element of EPub."
   (unless   (emacspeak-epub-p epub) (error "Invalid epub"))
   (let ((base (emacspeak-epub-base epub))
         (content nil)
-        (default-process-coding-system (cons 'utf-8 'utf-8))
-        (coding-system-for-read 'utf-8)
-        )
+        (emacspeak-xslt-options "--nonet --novalid")
+        (emacspeak-we-xsl-p nil))
     (unless (string-match (format "^%s" base) element)
       (setq element (concat base element)))
     (setq content (emacspeak-epub-get-contents epub element))
@@ -242,10 +244,9 @@
          (emacspeak-speak-rest-of-buffer))
      'at-end)
     (with-current-buffer content
-      (emacspeak-webutils-with-xsl-environment
-       style nil
-       "--nonet --novalid"; options
-       (browse-url-of-buffer)))))
+      (when style
+        (emacspeak-xslt-region style   (point-min) (point-max)))
+      (browse-url-of-buffer))))
 
 (defvar emacspeak-epub-files-command
   (format "%s -1 %%s | grep \.html*$ | sort" emacspeak-epub-zip-info)
@@ -285,7 +286,7 @@ Useful if table of contents in toc.ncx is empty."
        'at-end)
       (browse-url-of-buffer))))
 
-(defvar epub-toc-xsl (expand-file-name "epub-toc.xsl" emacspeak-xslt-directory)
+(defvar epub-toc-xsl (emacspeak-xslt-get "epub-toc.xsl")
   "XSL to process .ncx file.")
 
 (defun emacspeak-epub-browse-toc (epub)
@@ -637,6 +638,8 @@ Suitable for text searches."
     (switch-to-buffer buffer)
     (emacspeak-speak-mode-line)
     (emacspeak-auditory-icon 'open-object)))
+
+;;;###autoload
 (defun emacspeak-epub-eww (epub-file)
   "Display entire book  using EWW from EPub in a buffer.
 Suitable for text searches."
@@ -666,9 +669,7 @@ Suitable for text searches."
                           (shell-quote-argument f)))
             (insert (shell-command-to-string command ))
             (goto-char (point-max)))
-                                        ;(eww-display-html  'utf-8 "")
-      )
-    (switch-to-buffer buffer)))
+      (browse-url-of-buffer))))
 
 (defvar emacspeak-epub-google-search-template
   "http://books.google.com/books/feeds/volumes?min-viewability=full&epub=epub&q=%s"
@@ -676,7 +677,7 @@ Suitable for text searches."
 
 ;;;###autoload
 (defun emacspeak-epub-google (query)
-  "Search for Epubs from Gooble Books."
+  "Search for Epubs from Google Books."
   (interactive "sGoogle Books Query: ")
   (declare (special emacspeak-epub-google-search-template))
   (emacspeak-feeds-atom-display
@@ -790,7 +791,7 @@ Optional interactive prefix arg author-first prints author at the
   (emacspeak-auditory-icon 'task-done))
 
 (define-derived-mode emacspeak-epub-mode special-mode
-  "EPub Interaction On The Emacspeak Audio Desktop"
+                     "EPub Interaction On The Emacspeak Audio Desktop"
   "An EPub Front-end.
 Letters do not insert themselves; instead, they are commands.
 \\<emacspeak-epub-mode-map>
@@ -814,12 +815,12 @@ Letters do not insert themselves; instead, they are commands.
         ("\C-a" emacspeak-epub-bookshelf-add-directory)
         ("\C-d" emacspeak-epub-bookshelf-remove-directory)
         ("\C-k" emacspeak-epub-delete)
-        ("\C-l" emacspeak-epub-bookshelf-redraw)
+        ("C-l" emacspeak-epub-bookshelf-redraw)
         ("\C-m" emacspeak-epub-open)
         ("\C-o" emacspeak-epub-bookshelf-open-epub)
         ("\C-x\C-q" emacspeak-epub-bookshelf-refresh)
         ("\C-x\C-s" emacspeak-epub-bookshelf-save)
-        ("\M-s" emacspeak-epub-bookshelf-save)
+        ("M-s" emacspeak-epub-bookshelf-save)
         ("a" emacspeak-epub-bookshelf-add-epub)
         ("b" emacspeak-epub-bookshelf-open)
         ("c" emacspeak-epub-bookshelf-clear)
@@ -827,12 +828,13 @@ Letters do not insert themselves; instead, they are commands.
         ("e" emacspeak-epub-eww)
         ("f" emacspeak-epub-browse-files)
         ("g" emacspeak-epub-google)
+        ("l" emacspeak-epub-locate-epubs)
         ("n" next-line)
         ("o" emacspeak-epub-open)
         ("p" previous-line)
         ("r" emacspeak-epub-bookshelf-rename)
         ("t" emacspeak-epub-fulltext)
-        ([return] emacspeak-epub-open)
+        ("RET" emacspeak-epub-open)
         )
       do
       (emacspeak-keymap-update emacspeak-epub-mode-map k))
@@ -1072,7 +1074,7 @@ Searches for matches in both  Title and Author."
     (dtk-speak-and-echo  (format "Added %d books" (length results)))))
 
 (define-derived-mode emacspeak-calibre-mode special-mode
-  "Calibre Interaction On The Emacspeak Audio Desktop"
+                     "Calibre Interaction On The Emacspeak Audio Desktop"
   "A Calibre Front-end.
 Letters do not insert themselves; instead, they are commands.
 \\<emacspeak-calibre-mode-map>
@@ -1097,9 +1099,6 @@ Letters do not insert themselves; instead, they are commands.
 (declaim (special emacspeak-calibre-mode-map))
 (define-key emacspeak-calibre-mode-map [Return] 'emacspeak-epub-calibre-dired-at-point )
 
-(declaim (special emacspeak-calibre-mode-map))
-(define-key emacspeak-calibre-mode-map [Return] 'emacspeak-epub-calibre-dired-at-point)
-(define-key emacspeak-calibre-mode-map "\C-m" 'emacspeak-epub-calibre-dired-at-point)
 (defun emacspeak-epub-calibre-results ()
   "Show most recent Calibre search results."
   (interactive)
@@ -1133,6 +1132,14 @@ Letters do not insert themselves; instead, they are commands.
     (emacspeak-speak-line)))
 
 ;;}}}
+;;{{{ Locate epub using Locate:
+(defun emacspeak-epub-locate-epubs (pattern)
+  "Locate epub files using locate."  (interactive "sSearch Pattern: ")
+  (let ((locate-make-command-line #'(lambda (s) (list locate-command "-i" s))))
+    (funcall-interactively #'locate-with-filter pattern ".epub$")))
+
+;;}}}
+
 (provide 'emacspeak-epub)
 ;;{{{ end of file
 
