@@ -1,5 +1,5 @@
 ;;; emacspeak-eterm.el --- Speech enable eterm -- Emacs' terminal emulator  term.el
-;;; $Id: emacspeak-eterm.el 8534 2013-11-13 01:43:12Z tv.raman.tv $
+;;; $Id$
 ;;; $Author: tv.raman.tv $ 
 ;;; Description:  Emacspeak extension to speech enable eterm. 
 ;;; Keywords: Emacspeak, Eterm, Terminal emulation, Spoken Output
@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2011, T. V. Raman 
+;;;Copyright (C) 1995 -- 2015, T. V. Raman 
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved. 
 ;;;
@@ -168,11 +168,7 @@ Useful when eterm is in review mode.")
     (define-key term-raw-map
       (concat emacspeak-eterm-prefix emacspeak-eterm-prefix) 'emacspeak-eterm-maybe-send-raw)
     (define-key emacspeak-eterm-keymap emacspeak-eterm-raw-prefix
-      term-raw-map)
-;;; handle emacs 21 wierdness 
-    (local-unset-key "\eO")
-    (local-unset-key "\e[")
-    ))
+      term-raw-map)))
 
 ;;}}}
 ;;{{{  voice definitions  for eterm  highlight, underline etc
@@ -397,7 +393,7 @@ Argument COUNT specifies number of columns by which to move."
   (declare (special emacspeak-eterm-pointer ))
   (save-excursion
     (goto-char emacspeak-eterm-pointer )
-    (beginning-of-line)
+    (forward-line 0)
     (set-marker emacspeak-eterm-pointer (point ))
     (when (ems-interactive-p )
       (dtk-stop)
@@ -504,7 +500,7 @@ Optional argument COUNT specifies how many changes to skip."
   (interactive "p")
   (declare (special emacspeak-eterm-pointer))
   (setq count (or count 1 ))
-  (let ((current (get-text-property emacspeak-eterm-pointer 'personality ))
+  (let ((current (dtk-get-style emacspeak-eterm-pointer))
         (found nil))
     (save-excursion
       (goto-char emacspeak-eterm-pointer)
@@ -523,7 +519,7 @@ Optional argument COUNT specifies how many changes to skip."
   (interactive "p")
   (declare (special emacspeak-eterm-pointer term-home-marker))
   (setq count (or count 1 ))
-  (let ((current (get-text-property emacspeak-eterm-pointer 'personality ))
+  (let ((current (dtk-get-style emacspeak-eterm-pointer))
         (found nil))
     (save-excursion
       (goto-char emacspeak-eterm-pointer)
@@ -546,7 +542,7 @@ Use command \\[emacspeak-eterm-toggle-review].")
 
 (defun emacspeak-eterm-toggle-review ()
   "Toggle state of eterm review. 
-In review mode, you can move around the terminal and listen to the contnets 
+In review mode, you can move around the terminal and listen to the contents 
 without sending input to the terminal itself."
   (interactive)
   (declare (special emacspeak-eterm-review-p 
@@ -754,7 +750,7 @@ Argument ETERM-WINDOW specifies a predefined eterm window."
                      (buffer-substring start (point))
                      lines)
                     (forward-line 1)
-                    (beginning-of-line)
+                    (forward-line 0)
                     (forward-char (car top-left))
                     (setq start (point)))
                   (setq lines (nreverse lines ))
@@ -763,7 +759,7 @@ Argument ETERM-WINDOW specifies a predefined eterm window."
                (left-stretch
                 (let  ((lines nil))
                   (goto-char start )
-                  (beginning-of-line)
+                  (forward-line 0)
                   (setq start (point))
                   (while (< start end )
                     (forward-char (car bottom-right ))
@@ -771,7 +767,8 @@ Argument ETERM-WINDOW specifies a predefined eterm window."
                      (buffer-substring start (point ))
                      lines)
                     (forward-line 1)
-                    (beginning-of-line)
+                    (forward-line 0)
+
                     (setq start (point)))
                   (setq lines (nreverse lines ))
                   (mapconcat 'identity
@@ -946,6 +943,7 @@ non-negative integer ")
   "Window id used to filter screen activity.")
 
 (make-variable-buffer-local 'emacspeak-eterm-filter-window)
+;;;###autoload
 (defun emacspeak-eterm-set-filter-window (flag)
   "Prompt for the id of a predefined window,
 and set the `filter' window to it.
