@@ -1,5 +1,5 @@
 ;;; emacspeak-gnus.el --- Speech enable GNUS -- Fluent spoken access to usenet
-;;; $Id: emacspeak-gnus.el 9072 2014-04-16 15:27:01Z tv.raman.tv $
+;;; $Id$
 ;;; $Author: tv.raman.tv $ 
 ;;; Description:  Emacspeak extension to speech enable Gnus
 ;;; Keywords: Emacspeak, Gnus, Advice, Spoken Output, News
@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2011, T. V. Raman 
+;;;Copyright (C) 1995 -- 2015, T. V. Raman 
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved. 
 ;;;
@@ -39,11 +39,11 @@
 
 ;;{{{  Introduction:
 
-;;; Commentary
+;;; Commentary:
 
-;;; This module advices gnus to speak. 
+;;; This module advises gnus to speak. 
 ;;; Updating support in 2014 (Emacspeak is nearly 20 years old)
-
+;;; Code:
 ;;}}}
 ;;{{{ requires
 (require 'cl)
@@ -216,77 +216,21 @@ reading news."
 
 ;;}}}
 ;;{{{  Newsgroup selection
-
-(defadvice gnus-group-select-group (before emacspeak pre act)
-  "Provide auditory feedback.
- Produce an auditory icon if possible."
-  (when (ems-interactive-p )
-    (emacspeak-auditory-icon 'open-object)))
-
-(defadvice gnus-group-first-unread-group (after emacspeak pre act)
-  "Provide auditory feedback.
- Produce an auditory icon if possible."
-  (when (ems-interactive-p )
-    (emacspeak-auditory-icon 'select-object)
-    (emacspeak-speak-line)))
-
-(defadvice gnus-group-read-group  (after  emacspeak pre act)
-  "Speak the first article line.
- Produce an auditory icon indicating 
-an object has been opened."
-  (when (ems-interactive-p ) 
-    (emacspeak-auditory-icon 'open-object)
-    (dtk-speak (gnus-summary-article-subject))))
-
-(defadvice gnus-group-prev-group (around emacspeak pre act)
-  "Speak the newsgroup line.
- Produce an auditory icon if possible."
-  (let ((saved-point (point )))
-    (when (ems-interactive-p )
-      (emacspeak-auditory-icon 'select-object))
-    ad-do-it
-    (when (ems-interactive-p )
-      (if (= saved-point (point))
-          (dtk-speak "No more newsgroups ")
-        (emacspeak-speak-line))))
-  ad-return-value)
-
-(defadvice gnus-group-prev-unread-group (around emacspeak pre act)
-  "Speak the newsgroup line.
- Produce an auditory icon if possible."
-  (let ((saved-point (point )))
-    (when (ems-interactive-p )
-      (emacspeak-auditory-icon 'select-object))
-    ad-do-it
-    (when (ems-interactive-p )
-      (if (= saved-point (point))
-          (dtk-speak "No more newsgroups ")
-        (emacspeak-speak-line))))
-  ad-return-value)
-
-(defadvice gnus-group-next-group (around emacspeak pre act)
-  "Speak the newsgroup line.
- Produce an auditory icon if possible."
-  (let ((saved-point (point )))
-    (when (ems-interactive-p ) 
-      (emacspeak-auditory-icon 'select-object))
-    ad-do-it
-    (when (ems-interactive-p )
-      (if (= saved-point (point))
-          (dtk-speak "No more newsgroups")
-        (emacspeak-speak-line)))))
-
-(defadvice gnus-group-next-unread-group (around emacspeak pre act)
-  "Speak the newsgroup line.
- Produce an auditory icon if possible."
-  (let ((saved-point (point )))
-    (when (ems-interactive-p )
-      (emacspeak-auditory-icon 'select-object))
-    ad-do-it
-    (when (ems-interactive-p )
-      (if (= saved-point (point))
-          (dtk-speak "No more newsgroups")
-        (emacspeak-speak-line)))))
+(loop
+ for f in
+ '(gnus-group-select-group gnus-group-first-unread-group
+                           gnus-group-read-group
+                           gnus-group-prev-group gnus-group-next-group
+                           gnus-group-prev-unread-group  gnus-group-next-unread-group
+                           gnus-group-get-new-news-this-group
+                           )
+ do
+ (eval
+  `(defadvice ,f (after emacspeak pre act)
+     "Provide auditory feedback."
+     (when (ems-interactive-p )
+       (emacspeak-auditory-icon 'select-object)
+       (emacspeak-speak-line)))))
 
 (defadvice gnus-group-unsubscribe-current-group (after emacspeak pre act)
   "Produce an auditory icon indicating
@@ -309,13 +253,6 @@ this group is being deselected."
     (emacspeak-auditory-icon 'yank-object)
     (emacspeak-speak-line)))
 
-(defadvice gnus-group-get-new-news-this-group  (after emacspeak pre act)
-  "Provide auditory feedback.
- Produce an auditory icon if possible."
-  (when (ems-interactive-p )
-    (emacspeak-auditory-icon 'select-object)
-    (emacspeak-speak-line)))
-
 (defadvice gnus-group-list-groups (after emacspeak pre act)
   "Provide auditory feedback.
  Produce an auditory icon if possible."
@@ -729,9 +666,10 @@ Produce an auditory icon if possible."
 (defadvice gnus-summary-show-article (after emacspeak pre act)
   "Start speaking the article. "
   (when (ems-interactive-p )
-    (emacspeak-auditory-icon 'open-object)
-    (emacspeak-hide-all-blocks-in-buffer)
-    (emacspeak-gnus-speak-article-body)))
+    (with-current-buffer gnus-article-buffer
+      (emacspeak-auditory-icon 'open-object)
+      (emacspeak-hide-all-blocks-in-buffer)
+      (emacspeak-gnus-speak-article-body))))
 
 (defadvice gnus-summary-next-page (after emacspeak pre act)
   "Speak the next pageful "
@@ -943,7 +881,6 @@ Helps to prevent words from being spelled instead of spoken."
    (gnus-summary-high-ancient voice-smoothen-extra)
    (gnus-summary-low-ancient voice-smoothen-extra)
    (gnus-summary-normal-undownloaded voice-bolden-and-animate)
-   (gnus-summary-high-undownloadedvoice-bolden-and-animate)
    (gnus-summary-low-undownloaded voice-bolden-and-animate)
    (gnus-summary-low-unread voice-bolden-medium)
    (gnus-summary-high-unread voice-brighten-extra)
