@@ -1,5 +1,5 @@
 ;;; emacspeak-ido.el --- speech-enable ido
-;;; $Id: emacspeak-ido.el 9116 2014-04-30 16:23:49Z tv.raman.tv $
+;;; $Id$
 ;;; $Author: tv.raman.tv $
 ;;; Description:   extension to speech enable ido
 ;;; Keywords: Emacspeak, Audio Desktop
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (C) 1995 -- 2011, T. V. Raman<raman@cs.cornell.edu>
+;;; Copyright (C) 1995 -- 2015, T. V. Raman<raman@cs.cornell.edu>
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -72,18 +72,18 @@
 (defadvice ido-exhibit (after emacspeak pre act comp)
   "Speak first of the displayed matches."
   (when (and ido-matches
-             (sit-for 0.3))
-    (emacspeak-auditory-icon 'progress))
-  (dtk-speak
-   (concat 
-    (car ido-matches)
-    (format " %d choices: " (length ido-matches))
-    (minibuffer-contents)
-    (if(or (null ido-current-directory)
-           (string-equal ido-current-directory emacspeak-ido-cache-current-directory))
-        " "
-      (format "In directory: %s"
-              ido-current-directory)))))
+             (sit-for 0.5))
+    (emacspeak-auditory-icon 'progress)
+    (dtk-speak
+     (concat 
+      (car ido-matches)
+      (format " %d choices: " (length ido-matches))
+      (minibuffer-contents)
+      (if(or (null ido-current-directory)
+             (string-equal ido-current-directory emacspeak-ido-cache-current-directory))
+          " "
+        (format "In directory: %s"
+                ido-current-directory))))))
 
 ;;}}}
 ;;{{{ speech-enable interactive commands:
@@ -205,6 +205,11 @@ The default value of 12 is too high for using ido effectively with speech. "
   (when (ems-interactive-p )
     (emacspeak-auditory-icon 'close-object)))
 
+(defadvice ido-bury-buffer-at-head (after emacspeak pre act comp)
+  "Provide auditory icon."
+  (when (ems-interactive-p )
+    (emacspeak-auditory-icon 'close-object)))
+
 (defadvice ido-kill-buffer (after emacspeak pre act comp)
   "Provide auditory icon."
   (when (ems-interactive-p )
