@@ -1,5 +1,5 @@
 ;;; emacspeak-python.el --- Speech enable Python development environment
-;;; $Id: emacspeak-py.el 9473 2014-10-06 16:20:32Z tv.raman.tv $
+;;; $Id$
 ;;; $Author: tv.raman.tv $ 
 ;;; Description: Auditory interface to python mode
 ;;; Keywords: Emacspeak, Speak, Spoken Output, python
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2011, T. V. Raman
+;;; Copyright (c) 1995 -- 2015, T. V. Raman
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -42,19 +42,19 @@
 
 ;;; Commentary:
 
-;;; This speech-enables python-mode available on sourceforge
+;;; This speech-enables python-mode available on sourceforge and ELPA
 
 ;;; Code:
 
 ;;}}}
 ;;{{{  Required modules
-
+(require 'cl)
 (require 'emacspeak-preamble)
-
+(eval-when-compile
+  (require 'python-mode "python-mode" 'no-error))
 ;;}}}
-;;{{{ Advice interactive commands:
-
 ;;{{{  electric editing
+
 (unless (and (boundp 'post-self-insert-hook)
              post-self-insert-hook
              (memq 'emacspeak-post-self-insert-hook post-self-insert-hook))
@@ -135,20 +135,20 @@
 
 ;;}}}
 ;;{{{  whitespace management and indentation
-(loop for f in
-      (list 'py-fill-paragraph
-            'py-fill-comment
-            'py-fill-string)
-      do
-      (eval
-       `(defadvice ,f (after emacspeak pre act comp)
-          "Provide auditory feedback."
-          (when (ems-interactive-p )
-            (emacspeak-auditory-icon 'fill-object)))))
+
+(loop
+ for f in
+ (list 'py-fill-paragraph 'py-fill-comment 'py-fill-string)
+ do
+ (eval
+  `(defadvice ,f (after emacspeak pre act comp)
+     "Provide auditory feedback."
+     (when (ems-interactive-p )
+       (emacspeak-auditory-icon 'fill-object)))))
 
 (defadvice py-newline-and-indent(after emacspeak pre act comp)
   "Speak line so we know current indentation"
-  (when t;(ems-interactive-p )
+  (when (ems-interactive-p )
     (dtk-speak-using-voice voice-annotate
                            (format
                             "indent %s"
@@ -171,6 +171,7 @@
      (format "Right shifted block  containing %s lines"
              (count-lines  (region-beginning)
                            (region-end))))))
+
 (defadvice py-indent-region (after emacspeak pre act comp)
   "Speak number of lines that were shifted"
   (when (ems-interactive-p )
@@ -190,65 +191,65 @@
 
 ;;}}}
 ;;{{{  buffer navigation
-(defadvice py-previous-statement (after emacspeak pre act comp)
-  "Speak current statement after moving"
-  (when (ems-interactive-p )
-    (emacspeak-speak-line)
-    (emacspeak-auditory-icon 'large-movement)))
-(defadvice py-next-statement (after emacspeak pre act comp)
-  "Speak current statement after moving"
-  (when (ems-interactive-p )
-    (emacspeak-speak-line)
-    (emacspeak-auditory-icon 'large-movement)))
+(loop
+ for f in
+ '(
+   py-down py-up
+           py-backward-statement py-forward-statement
+           py-goto-block-up  py-go-to-beginning-of-comment
+           py-beginning-of-statement py-end-of-statement
+           py-beginning-of-block py-end-of-block
+           py-beginning-of-clause py-end-of-clause
+           py-next-statement py-previous-statement
+           py-beginning-of-def-or-class py-end-of-def-or-class)
+ do                  
+ (eval
+  `(defadvice ,f (after emacspeak pre act comp)
+     "Speak current statement after moving"
+     (when (ems-interactive-p )
+       (emacspeak-speak-line)
+       (emacspeak-auditory-icon 'large-movement)))))
 
-(defadvice py-goto-block-up (after emacspeak pre act comp)
-  "Speak current statement after moving"
-  (when (ems-interactive-p )
-    (emacspeak-speak-line)
-    (emacspeak-auditory-icon 'large-movement)))
+(loop
+ for  f in
+ '(
+   py-mark-class-bol py-mark-clause py-mark-clause-bol py-mark-comment
+                     py-mark-comment-bol py-mark-def py-mark-def-bol
+                     py-mark-def-or-class py-mark-def-or-class-bol py-mark-except-block
+                     py-mark-except-block-bol py-mark-expression py-mark-expression-bol
+                     py-mark-if-block py-mark-if-block-bol py-mark-line py-mark-line-bol
+                     py-mark-minor-block py-mark-minor-block-bol py-mark-paragraph
+                     py-mark-paragraph-bol py-mark-partial-expression
+                     py-mark-partial-expression-bol py-mark-section py-mark-statement
+                     py-mark-statement-bol py-mark-top-level py-mark-top-level-bol
+                     py-mark-try-block py-mark-try-block-bol )                 
+ do
+ (eval
+  `(defadvice ,f (after emacspeak pre act comp)
+     "Speak number of lines marked"
+     (when (ems-interactive-p )
+       (dtk-speak
+        (format
+         "Marked block containing %s lines"
+         (count-lines (region-beginning) (region-end))))
+       (emacspeak-auditory-icon 'mark-object)))))
 
-(defadvice py-beginning-of-def-or-class (after emacspeak pre act comp)
-  "Speak current statement after moving"
-  (when (ems-interactive-p )
-    (emacspeak-speak-line)
-    (emacspeak-auditory-icon 'large-movement)))
+(loop
+ for f in
+ '(
 
-(defadvice beginning-of-python-def-or-class (after emacspeak pre act comp)
-  "Speak current statement after moving"
-  (when (ems-interactive-p )
-    (emacspeak-speak-line)
-    (emacspeak-auditory-icon 'large-movement)))
-
-(defadvice end-of-python-def-or-class (after emacspeak pre act comp)
-  "Speak current statement after moving"
-  (when (ems-interactive-p )
-    (emacspeak-speak-line)
-    (emacspeak-auditory-icon 'large-movement)))
-
-(defadvice py-end-of-def-or-class (after emacspeak pre act comp)
-  "Speak current statement after moving"
-  (when (ems-interactive-p )
-    (emacspeak-speak-line)
-    (emacspeak-auditory-icon 'large-movement)))
-
-(defadvice py-mark-block (after emacspeak pre act comp)
-  "Speak number of lines marked"
-  (when (ems-interactive-p )
-    (dtk-speak
-     (format "Marked block containing %s lines"
-             (count-lines (region-beginning)
-                          (region-end))))
-    (emacspeak-auditory-icon 'mark-object)))
-(defadvice py-narrow-to-defun (after emacspeak pre act comp)
-  "Provide auditory feedback."
-  (when (ems-interactive-p )
-    (message "%s %s lines"
-             (save-excursion
-               (goto-char (point-min))
-               (buffer-substring (line-beginning-position)
-                                 (line-end-position)))
-             (count-lines (point-min)
-                          (point-max)))))
+   Possible completions are:
+            py-narrow-to-block  py-narrow-to-block-or-clause    py-narrow-to-class
+            py-narrow-to-clause         py-narrow-to-def        py-narrow-to-def-or-class
+            py-narrow-to-statement
+            )
+ do
+ (eval
+  `(defadvice ,f (after emacspeak pre act comp)
+     "Provide auditory feedback."
+     (when (ems-interactive-p )
+       (message "Narrowed  %s lines"
+                (count-lines (point-min) (point-max)))))))
 
 (defadvice py-mark-def-or-class (after emacspeak pre act comp)
   "Speak number of lines marked"
@@ -289,45 +290,6 @@
 
 ;;}}}
 
-;;}}}
-;;{{{ Additional navigation
-(defun emacspeak-py-previous-block()
-  "Move backward to the beginning of the current block.
-If already at the beginning then move to previous block."
-  (interactive)
-  (let ((start (point)))
-    (beginning-of-python-def-or-class)
-    (unless (eq start (point))
-      (beginning-of-line)
-      (emacspeak-speak-line)
-      (emacspeak-auditory-icon 'large-movement))))
-
-(defun emacspeak-py-next-block()
-  "Move forward to the beginning of the next block."
-  (interactive)
-  (end-of-python-def-or-class)
-  (skip-syntax-forward " ")
-  (forward-line 1)
-  (beginning-of-line)
-  (emacspeak-speak-line)
-  (emacspeak-auditory-icon 'large-movement))
-
-;;}}}
-;;{{{ keybindings
-
-(progn
-  (declaim (special  python-mode-map))
-  (define-key python-mode-map "\M-a" 'beginning-of-python-def-or-class)
-  (define-key python-mode-map "\M-e" 'end-of-python-def-or-class)
-  (define-key python-mode-map "\M-n" 'py-next-statement)
-  (define-key python-mode-map "\M-p" 'py-previous-statement)
-  (define-key python-mode-map "\C-\M-u" 'py-goto-block-up)
-  (define-key python-mode-map "\C-\M-n" 'emacspeak-py-next-block)
-  (define-key python-mode-map "\C-\M-p" 'emacspeak-py-previous-block)
-  )
-(add-hook 'python-mode-hook
-          'emacspeak-setup-programming-mode)
-;;}}}
 ;;{{{ Voice Mappings:
 (voice-setup-add-map
  '(
