@@ -1,5 +1,5 @@
 ;;; emacspeak-replace.el --- Speech enable interactive search and replace
-;;; $Id: emacspeak-replace.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Id$
 ;;; $Author: tv.raman.tv $ 
 ;;; Description:  Emacspeak extension for replace.el
 ;;; Keywords: Emacspeak, Speech feedback, query replace (replace.el)
@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2007, T. V. Raman 
+;;;Copyright (C) 1995 -- 2015, T. V. Raman 
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved. 
 ;;;
@@ -44,9 +44,9 @@
 
 ;;}}}
 ;;{{{  Introduction:
-
+;;; Commentary:
 ;;; This module causes emacs' replacement functions to use voice locking
-
+;;; Code:
 ;;}}}
 ;;{{{  define personalities
 
@@ -89,8 +89,7 @@ that is being replaced."
             emacspeak-speak-messages t))))
 
 (defadvice query-replace (around emacspeak pre act compile)
-  "Stop message from chattering.
- Turn on voice lock temporarily. "
+  "Stop message from chattering."
   (declare (special voice-lock-mode ))
   (let ((saved-voice-lock voice-lock-mode)
         (emacspeak-speak-messages nil))
@@ -105,7 +104,10 @@ that is being replaced."
       (emacspeak-auditory-icon 'task-done)
       (setq voice-lock-mode saved-voice-lock
             emacspeak-speak-messages t))))
-
+(defadvice perform-replace (around emacspeak pre act  comp)
+  "Silence help message."
+  (let ((emacspeak-speak-messages nil))
+    ad-do-it))
 (defadvice replace-highlight (before  emacspeak pre act)
   "Voicify and speak the line containing the replacement. "
   (declare (special emacspeak-replace-highlight-on
@@ -127,7 +129,7 @@ that is being replaced."
                   emacspeak-replace-start from
                   emacspeak-replace-end  to 
                   emacspeak-replace-saved-personality
-                  (get-text-property  from 'personality))
+                  (dtk-get-style from))
             (and from to 
                  (put-text-property from to 'personality
                                     emacspeak-replace-personality ))
@@ -154,7 +156,6 @@ that is being replaced."
                      emacspeak-replace-end nil
                      emacspeak-replace-highlight-on nil)))
       (error  nil ))))
-    
 
 ;;}}}
 (provide 'emacspeak-replace)
@@ -162,7 +163,7 @@ that is being replaced."
 
 ;;; local variables:
 ;;; folded-file: t
-;;; byte-compile-dynamic: t
+;;; byte-compile-dynamic: nil
 ;;; end: 
 
 ;;}}}
