@@ -1,5 +1,5 @@
 ;;; emacspeak-setup.el --- Setup Emacspeak environment --loaded to start Emacspeak
-;;; $Id: emacspeak-setup.el 9594 2014-11-26 01:17:48Z tv.raman.tv $
+;;; $Id$
 ;;; $Author: tv.raman.tv $
 ;;; Description:  File for setting up and starting Emacspeak
 ;;; Keywords: Emacspeak, Setup, Spoken Output
@@ -15,7 +15,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;;Copyright (C) 1995 -- 2011, T. V. Raman
+;;;Copyright (C) 1995 -- 2015, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -40,6 +40,14 @@
 
 ;;; Commentary:
 ;;; Entry point for Emacspeak.
+;;; The simplest and most basic way to start emacspeak is:
+;;; emacs -q -l <emacspeak-dir>/lisp/emacspeak-setup.el
+;;; The above starts a vanilla Emacs with just Emacspeak loaded.
+;;; Once the above has been verified to work,
+;;; You can  add
+;;; (load-library "emacspeak-setup")
+;;; To your .emacs file.
+;;; See tvr/emacs-startup.el in the Emacspeak Git repository for  my setup.
 
 ;;; Code:
 
@@ -49,8 +57,7 @@
 (eval-when-compile (require 'cl))
 (declaim  (optimize  (safety 0) (speed 3)))
 (require 'custom)
-(eval-when (compile)
-  (require 'emacspeak-preamble))
+(eval-when (compile) (require 'emacspeak-preamble))
 
 ;;}}}
 ;;{{{  Define locations
@@ -59,14 +66,17 @@
 (defvar emacspeak-directory
   (expand-file-name "../" (file-name-directory load-file-name))
   "Directory where emacspeak is installed. ")
+
 ;;;###autoload
 (defvar emacspeak-lisp-directory
   (expand-file-name  "lisp/" emacspeak-directory)
   "Directory where emacspeak lisp files are  installed. ")
+
 ;;;###autoload
 (defvar emacspeak-sounds-directory
   (expand-file-name  "sounds/" emacspeak-directory)
   "Directory containing auditory icons for Emacspeak.")
+
 ;;;###autoload
 (defvar emacspeak-xslt-directory
   (expand-file-name "xsl/" emacspeak-directory)
@@ -75,55 +85,67 @@
 ;;;###autoload
 (defvar emacspeak-etc-directory
   (expand-file-name  "etc/" emacspeak-directory)
-  "Directory containing miscellaneous files  for
-  Emacspeak.")
+  "Directory containing miscellaneous files  for Emacspeak.")
+
 ;;;###autoload
 (defvar emacspeak-servers-directory
   (expand-file-name  "servers/" emacspeak-directory)
-  "Directory containing speech servers  for
-  Emacspeak.")
+  "Directory containing speech servers  for Emacspeak.")
+
 ;;;###autoload
 (defvar emacspeak-info-directory
   (expand-file-name  "info/" emacspeak-directory)
   "Directory containing  Emacspeak info files.")
-;;;###autoload
-(defvar emacspeak-resource-directory (expand-file-name "~/.emacspeak/")
-  "Directory where Emacspeak resource files such as
-pronunciation dictionaries are stored. ")
-;;;###autoload
-(defvar emacspeak-readme-file
-  (expand-file-name "README"
-                    emacspeak-directory)
-  "README file from where we get SVN revision number.")
 
 ;;;###autoload
-(defconst emacspeak-codename
-  "NiceDog"
+(defvar emacspeak-resource-directory (expand-file-name "~/.emacspeak/")
+  "Directory where Emacspeak resource files
+such as pronunciation dictionaries are stored. ")
+
+;;;###autoload
+(defvar emacspeak-readme-file
+  (expand-file-name "README" emacspeak-directory)
+  "README file from where we get Git  revision number.")
+
+;;;###autoload
+(defvar emacspeak-media-extensions
+  (concat
+   "\\."
+   (regexp-opt
+    (list "wma" "wmv" "flv"
+          "m4a" "m4b" "flac"
+          "ogg" "mp3" "MP3" "mp4")
+    'parens)
+   "$")
+  "Extensions that match media files.")
+
+;;;###autoload
+(defvar emacspeak-codename
+  "SolidDog"
   "Code name of present release.")
 
 ;;;###autoload
-(defconst emacspeak-version
+(defsubst emacspeak-setup-get-revision ()
+  "Get SHA checksum of current revision that is suitable for spoken output."
+  (let ((default-directory emacspeak-directory))
+    (if (and (executable-find "git")
+             (file-exists-p (expand-file-name ".git"  emacspeak-directory)))
+        (substring
+         (shell-command-to-string  "git show HEAD | head -1 | cut -b 8- ")
+         0 6)
+      "")))
+
+;;;###autoload
+(defsubst emacspeak-xslt-get (style)
+  "Return fully qualified stylesheet path."
+  (expand-file-name style emacspeak-xslt-directory))
+
+;;;###autoload
+(defvar emacspeak-version
   (format
-   "41.0 %s:  %s"
+   "43.0 %s:  %s"
    emacspeak-codename
-   (cond
-    ((file-exists-p emacspeak-readme-file)
-     (let ((buffer (find-file-noselect emacspeak-readme-file))
-           (revision nil))
-       (save-current-buffer
-         (set-buffer buffer)
-         (goto-char (point-min))
-         (setq revision
-               (format "Revision %s"
-                       (or
-                        (nth 2 (split-string
-                                (buffer-substring-no-properties
-                                 (line-beginning-position)
-                                 (line-end-position))))
-                        "unknown"))))
-       (kill-buffer buffer)
-       revision))
-    (t "")))
+   (emacspeak-setup-get-revision))
   "Version number for Emacspeak.")
 
 ;;}}}
@@ -142,15 +164,11 @@ pronunciation dictionaries are stored. ")
   :type 'integer)
 
 ;;;###autoload
-(defcustom multispeech-default-speech-rate 225
-  "Default speech rate for multispeech."
-  :group 'tts
-  :type 'integer)
-;;;###autoload
 (defcustom dectalk-default-speech-rate 225
   "*Default speech rate at which TTS is started. "
   :group 'tts
   :type 'integer)
+
 ;;;###autoload
 (defcustom espeak-default-speech-rate 175
   "Default speech rate for eSpeak."
@@ -169,34 +187,62 @@ pronunciation dictionaries are stored. ")
 ;;;###autoload
 (defun emacspeak-tts-startup-hook ()
   "Default hook function run after TTS is started."
-  (declare (special tts-default-speech-rate))
-  (tts-configure-synthesis-setup)
-  (dtk-set-rate tts-default-speech-rate t)
-  (dtk-interp-sync))
+  (declare (special dtk-program))
+  (tts-configure-synthesis-setup dtk-program))
 
 (add-hook 'dtk-startup-hook 'emacspeak-tts-startup-hook)
 
+;;;###autoload
+(defcustom emacspeak-tts-use-notify-stream nil
+  "Set to true to use a separate TTS stream for notifications."
+  :type 'boolean
+  :group 'emacspeak)
+
+(defun emacspeak-tts-multistream-p (tts-engine)
+  "Checks if this tts-engine can support multiple streams."
+  (member tts-engine '("outloud" "32-outloud" "espeak" "mac"
+                       "cloud-outloud" "cloud-espeak" "cloud-mac")))
+
+(defun emacspeak-tts-notify-hook ()
+  "Starts up a notification stream if current synth supports  multiple invocations.
+Should be safe to use with any software TTS engine."
+  (declare (special dtk-program dtk-notify-process))
+  (unless (emacspeak-tts-multistream-p dtk-program)
+    (and (process-live-p dtk-notify-process) (delete-process dtk-notify-process)))
+  (when  (emacspeak-tts-multistream-p dtk-program) (dtk-notify-initialize)))
+
+(when emacspeak-tts-use-notify-stream
+  (add-hook 'dtk-startup-hook 'emacspeak-tts-notify-hook 'at-end))
+
 (defvar emacspeak-startup-hook nil)
 (defun emacspeak-setup-header-line ()
-  "Set up Emacspeak to show a default header line."
+  "Set up Emacspeak to speak a default header line."
   (declare (special emacspeak-use-header-line
-                    header-line-format
-                    emacspeak-header-line-format))
+                    header-line-format emacspeak-header-line-format))
   (when emacspeak-use-header-line
-    (setq header-line-format
-          emacspeak-header-line-format)))
+    (setq header-line-format emacspeak-header-line-format)))
 
 (defun emacspeak-tvr-startup-hook ()
   "Emacspeak startup hook that I use."
-  (load-library "emacspeak-alsaplayer")
   (load-library "emacspeak-webspace")
   (load-library "emacspeak-dbus"))
 
 (add-hook 'emacspeak-startup-hook 'emacspeak-setup-header-line)
 (add-hook 'emacspeak-startup-hook 'emacspeak-tvr-startup-hook)
 
+(defvar emacspeak-info-already-loaded nil
+  "Track info support load.")
+
+(add-hook
+ 'Info-mode-hook
+ #'(lambda ()
+     (unless emacspeak-info-already-loaded
+       (load-library "emacspeak-info")
+       (setq emacspeak-info-already-loaded t))))
+
 ;;}}}
 (emacspeak)
+
 (provide 'emacspeak-setup)
 ;;{{{  emacs local variables
 
