@@ -1,5 +1,5 @@
 ;;; emacspeak-sounds.el --- Defines Emacspeak auditory icons
-;;; $Id: emacspeak-sounds.el 9562 2014-11-15 17:13:41Z tv.raman.tv $
+;;; $Id$
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Module for adding sound cues to emacspeak
 ;;; Keywords:emacspeak, audio interface to emacs, auditory icons
@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2011, T. V. Raman
+;;;Copyright (C) 1995 -- 2015, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -83,9 +83,9 @@ use `emacspeak-toggle-auditory-icons' bound to
 ;;}}}
 ;;{{{ Setup Audio 
 ;;;###autoload
-(defun emacspeak-audio-setup ()
+(defun emacspeak-audio-setup (&optional prefix)
   "Call appropriate audio environment set command."
-  (interactive)
+  (interactive "P")
   (cond
    ((executable-find "amixer")
     (call-interactively 'amixer))
@@ -95,69 +95,16 @@ use `emacspeak-toggle-auditory-icons' bound to
 ;;}}}
 ;;{{{  Setup sound themes
 
-(defvar emacspeak-sounds-icon-list
-  '(
-    alarm
-    alert-user
-    ask-question
-    ask-short-question
-    button
-    center
-    close-object
-    delete-object
-    deselect-object
-    ellipses
-    fill-object
-    full
-    help
-    item
-    large-movement
-    left
-    mark-object
-    modified-object
-    n-answer
-    new-mail
-    news
-    no-answer
-    off
-    on
-    open-object
-    paragraph
-    progress
-    quit
-    right
-    save-object
-    scroll
-    search-hit
-    search-miss
-    section
-    select-object
-    shutdown
-    task-done
-    unmodified-object
-    warn-user
-    window-resize
-    y-answer
-    yank-object
-    yes-answer
-    )
-  "List of valid auditory icon names.
-If we add new icons we should declare them here. ")
-
-(defsubst emacspeak-sounds-icon-list ()
-  "Return the  list of auditory icons that are currently defined."
-  (declare (special emacspeak-sounds-icon-list))
-  emacspeak-sounds-icon-list)
-
 (defvar emacspeak-default-sound
   (expand-file-name
-   "default-8k/button.au"
+   "classic/button.au"
    emacspeak-sounds-directory)
   "Default sound to play if requested icon not found.")
 
 (defvar emacspeak-sounds-themes-table
   (make-hash-table)
   "Maps valid sound themes to the file name extension used by that theme.")
+
 ;;;###autoload
 (defun emacspeak-sounds-define-theme (theme-name file-ext)
   "Define a sounds theme for auditory icons. "
@@ -172,11 +119,12 @@ If we add new icons we should declare them here. ")
 
 ;;;###autoload
 (defcustom emacspeak-sounds-default-theme
-  (expand-file-name "default-8k/"
+  (expand-file-name "3d"
                     emacspeak-sounds-directory)
   "Default theme for auditory icons. "
   :type '(directory :tag "Sound Theme Directory")
   :group 'emacspeak-sounds)
+
 ;;;###autoload
 (defcustom emacspeak-play-program
   (cond
@@ -220,16 +168,15 @@ Do not set this by hand;
   "Predicate to test if theme is available."
   (file-exists-p
    (expand-file-name theme emacspeak-sounds-directory)))
+
 ;;;###autoload
 (defun emacspeak-sounds-select-theme  (theme)
   "Select theme for auditory icons."
   (interactive
    (list
     (expand-file-name
-     (read-directory-name "Theme: "
-                          emacspeak-sounds-directory))))
-  (declare (special emacspeak-sounds-current-theme
-                    emacspeak-sounds-themes-table))
+     (read-directory-name "Theme: " emacspeak-sounds-directory))))
+  (declare (special emacspeak-sounds-current-theme emacspeak-sounds-themes-table))
   (setq theme (expand-file-name theme emacspeak-sounds-directory))
   (unless (file-directory-p theme)
     (setq theme  (file-name-directory theme)))
@@ -264,8 +211,7 @@ Do not set this by hand;
                                (emacspeak-get-sound-filename sound-name ))))
 
 ;;}}}
-;;{{{  native player (emacs 21)
-
+;;{{{  native player (
 ;;;###autoload
 (defun emacspeak-native-auditory-icon (sound-name)
   "Play auditory icon using native Emacs player."
@@ -281,28 +227,47 @@ Do not set this by hand;
   "Serve auditory icon SOUND-NAME."
   (declare (special dtk-speaker-process))
   (process-send-string dtk-speaker-process
-                         (format "p %s\n"
-                                 (emacspeak-get-sound-filename sound-name ))))
+                       (format "p %s\n"
+                               (emacspeak-get-sound-filename sound-name ))))
 
 ;;}}}
 ;;{{{  Play an icon
-
+;;;###autoload
 (defcustom emacspeak-play-args "-q"
   "Set this to nil if using paplay from pulseaudio."
-  :type 'string
+  :type '(choice (string :tag "Arguments" "-q")
+		 (const :tag "None" nil))
   :group 'emacspeak-sounds)
 
 (defun emacspeak-play-auditory-icon (sound-name)
   "Produce auditory icon SOUND-NAME."
   (declare (special emacspeak-play-program emacspeak-play-args))
   (let ((process-connection-type nil))
-             (start-process
-              emacspeak-play-program nil emacspeak-play-program
-              emacspeak-play-args
-              (emacspeak-get-sound-filename sound-name)
-              "&")
-           (error
-            (message (error-message-string err)))))
+    (if emacspeak-play-args
+        (start-process
+         emacspeak-play-program nil emacspeak-play-program
+         emacspeak-play-args
+         (emacspeak-get-sound-filename sound-name)
+         "&")
+      (start-process
+       emacspeak-play-program nil emacspeak-play-program
+       (emacspeak-get-sound-filename sound-name)
+       "&"))))
+
+;;;###autoload
+(defcustom emacspeak-soxplay-command 
+  (when(executable-find "play")
+    (format "%s -v 1.2 %%s  earwax &" (executable-find "play")))
+  "Name of play executable from SoX"
+  :group 'emacspeak-sounds
+  :type 'string)
+(defun emacspeak-soxplay-auditory-icon (sound-name)
+  "Produce auditory icon SOUND-NAME.
+This uses SoX play and is specifically for use with headphones."
+  (declare (special emacspeak-soxplay-command))
+  (let ((icon (emacspeak-get-sound-filename sound-name)))
+    (call-process shell-file-name nil nil nil shell-command-switch
+                  (format emacspeak-soxplay-command icon))))
 
 ;;}}}
 ;;{{{  setup play function
@@ -312,6 +277,7 @@ Do not set this by hand;
 play : Launches play-program to play.
 Serve: Send a command to the speech-server to play.
 Queue : Add auditory icon to speech queue.
+soxplay: Use sox to apply effect earwax for headphones.
 Native : Use Emacs' builtin sound support.
 Use Serve when working with remote speech servers."
   :group 'emacspeak-sounds
@@ -319,6 +285,7 @@ Use Serve when working with remote speech servers."
           (const emacspeak-play-auditory-icon)
           (const emacspeak-serve-auditory-icon)
           (const emacspeak-native-auditory-icon)
+          (const emacspeak-soxplay-auditory-icon)
           (const emacspeak-queue-auditory-icon)))
 
 ;;;###autoload
@@ -383,19 +350,6 @@ emacspeak-queue-auditory-icon when using software TTS."
   (setq emacspeak-auditory-icon-function player))  (when (ems-interactive-p )
                                                      (emacspeak-auditory-icon 'select-object))
 
-;;}}}
-;;{{{ Show all icons
-
-(defun emacspeak-play-all-icons ()
-  "Plays all defined icons and speaks their names."
-  (interactive)
-  (mapcar
-   #'(lambda (f)
-       (emacspeak-auditory-icon f)
-       (dtk-speak (format "%s" f))
-       (sleep-for 2))
-   (emacspeak-sounds-icon-list)))
-
 ;;}}}
 ;;{{{ reset local player
 (defun emacspeak-sounds-reset-local-player ()
