@@ -1,5 +1,5 @@
 ;;; emacspeak-speedbar.el --- Speech enable speedbar -- Tool for context-sensitive navigation
-;;; $Id: emacspeak-speedbar.el 8146 2013-02-09 20:05:08Z tv.raman.tv $
+;;; $Id$
 ;;; $Author: tv.raman.tv $ 
 ;;; Description: Auditory interface to speedbar
 ;;; Keywords: Emacspeak, Speedbar
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2011, T. V. Raman
+;;; Copyright (c) 1995 -- 2015, T. V. Raman
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -57,7 +57,7 @@
 ;;{{{  Required modules
 
 (require 'emacspeak-preamble)
-(require 'speedbar nil t)
+(require 'speedbar "speedbar" 'no-error)
 ;;}}}
 ;;{{{ custom
 
@@ -236,20 +236,20 @@ An automatically updating speedbar consumes resources.")
 
 ;;}}}
 ;;{{{  hooks
-(declaim (special speedbar-key-map))
+(declaim (special speedbar-mode-map))
 (eval-when (load)
   )
 (defun emacspeak-speedbar-enter-hook ()
   "Actions taken when we enter the Speedbar"
-  (declare (special speedbar-key-map
+  (declare (special speedbar-mode-map
                     speedbar-hide-button-brackets-flag))
   (dtk-set-punctuations 'all)
   (setq speedbar-hide-button-brackets-flag t)
-  (define-key speedbar-key-map "f"
+  (define-key speedbar-mode-map "f"
     'emacspeak-speedbar-click)
-                                        ;(define-key speedbar-key-map "\M-n"
+                                        ;(define-key speedbar-mode-map "\M-n"
                                         ;'emacspeak-speedbar-forward)
-                                        ;(define-key speedbar-key-map "\M-p"
+                                        ;(define-key speedbar-mode-map "\M-p"
                                         ;'emacspeak-speedbar-backward)
   )
 
