@@ -1,5 +1,5 @@
 ;;; emacspeak-table.el --- Implements data model for table browsing
-;;; $Id: emacspeak-table.el 5222 2007-08-26 01:28:19Z tv.raman.tv $
+;;; $Id$
 ;;; $Author: tv.raman.tv $ 
 ;;; Description: Emacspeak table handling module
 ;;; Keywords:emacspeak, audio interface to emacs tables are structured
@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2007, T. V. Raman 
+;;;Copyright (C) 1995 -- 2015, T. V. Raman 
 ;;; Copyright (c) 1995 by T. V. Raman  
 ;;; All Rights Reserved. 
 ;;;
@@ -39,11 +39,14 @@
 
 ;;{{{  Introduction
 
+;;; Commentary:
 ;;; Implements a module that provides a high level interface to
 ;;; tabulated information.
+;;; Code:
 
 ;;}}}
 ;;{{{ requires
+
 (require 'emacspeak-preamble)
 
 ;;}}}
@@ -67,18 +70,16 @@
 ;;;###autoload
 (defun emacspeak-table-make-table (elements)
   "Construct a table object from elements."
-  (assert (vectorp elements) t
-          "Elements should be a vector of vectors" )
+  (assert (vectorp elements) t "Elements should be a vector of vectors" )
   (let ((table (cons-emacspeak-table :elements elements ))
         (row-h (make-vector (length  elements ) nil))
         (index 0))
-    (setf (emacspeak-table-column-header table ) (aref elements 0))
-    (loop for element across  elements 
-          do 
-          (assert (vectorp element) t
-                  "Row %s is not a vector" index)
-          (aset row-h index (aref element 0))
-          (incf index ))
+    (setf (emacspeak-table-column-header table ) (aref elements 0)) ;first row
+    (loop
+     for element across  elements do 
+     (assert (vectorp element) t "Row %s is not a vector" index)
+     (aset row-h index (aref element 0)) ; build column 0
+     (incf index ))
     (setf (emacspeak-table-row-header table) row-h)
     (setf (emacspeak-table-current-row table) 0)
     (setf (emacspeak-table-current-column table) 0)
@@ -89,9 +90,7 @@
 
 (defsubst emacspeak-table-this-element (table row column)
   (let ((elements (emacspeak-table-elements  table)))
-    (aref
-     (aref elements row)
-     column)))
+    (aref (aref elements row) column)))
 
 (defsubst emacspeak-table-current-element (table)
   (emacspeak-table-this-element table 
@@ -106,11 +105,10 @@
       ((elements (emacspeak-table-elements table ))
        (result (make-vector (length elements) nil))
        (index 0))
-    (loop for row across elements 
-          do
-          (aset result index
-                (aref row column))
-          (incf index))
+    (loop
+     for row across elements do
+     (aset result index (aref row column))
+     (incf index))
     result))
 
 (defsubst emacspeak-table-num-rows (table)
@@ -122,8 +120,8 @@
 (defsubst emacspeak-table-column-header-element (table column)
   (aref (emacspeak-table-column-header table) column))
 
-(defsubst emacspeak-table-row-header-element (table column)
-  (aref (emacspeak-table-row-header table) column))
+(defsubst emacspeak-table-row-header-element (table row)
+  (aref (emacspeak-table-row-header table) row))
 
 ;;}}}
 ;;{{{  enumerators
@@ -131,19 +129,21 @@
 (defun emacspeak-table-enumerate-rows (table callback &rest callback-args)
   "Enumerates the rows of a table.
 Calls callback once per row."
-  (loop for row across (emacspeak-table-elements table)
-        collect
-        (apply callback row callback-args )))
+  (loop
+   for row across (emacspeak-table-elements table)
+   collect
+   (apply callback row callback-args )))
 
 (defun emacspeak-table-enumerate-columns (table callback &rest callback-args)
   "Enumerate columns of a table.
 Calls callback once per column."
   (let ((elements (emacspeak-table-elements table )))
-    (loop for column   from 0 to (1- (length   elements))
-          collect
-          (apply callback
-                 (emacspeak-table-this-column table column)
-                 callback-args ))))
+    (loop
+     for column   from 0 to (1- (length   elements))
+     collect
+     (apply callback
+            (emacspeak-table-this-column table column)
+            callback-args ))))
 
 ;;}}}
 ;;{{{ finders 
@@ -157,13 +157,16 @@ Calls callback once per column."
                  (emacspeak-table-num-columns  table)))
         (count   (emacspeak-table-num-columns table))
         (found nil))
-    (loop for   i from 0   to count
-          and column = next then (% (incf column) count)
-          if  (funcall predicate  pattern
-                       (emacspeak-table-this-element table  index column))
-          do (setq found t )
-          until found
-          finally return (and found column))))
+    (loop
+     for   i from 0   to count
+     and column = next then (% (incf column) count)
+     if
+     (funcall predicate  pattern
+              (emacspeak-table-this-element table  index column))
+     do
+     (setq found t )
+     until found
+     finally return (and found column))))
 
 (defun emacspeak-table-find-match-in-column (table index pattern
                                                    &optional predicate)
@@ -184,6 +187,7 @@ Calls callback once per column."
 
 ;;}}}
 ;;{{{  Moving point:
+
 (defun emacspeak-table-goto-cell (table row column)
   "Move to a cell of the table"
   (let  ((row-count (emacspeak-table-num-rows table))
@@ -197,7 +201,6 @@ Calls callback once per column."
       (setf (emacspeak-table-current-column table) column))
      (t (error "Current table has %s rows and %s columns"
                row-count column-count )))))
-        
 
 (defun emacspeak-table-move-up (table &optional count)
   "Move up in the table if possible."
@@ -207,8 +210,9 @@ Calls callback once per column."
     (cond
      ((<= 0 new)
       (setf (emacspeak-table-current-row table) new))
-     (t (error "Cannot move up by %s rows from row %s"
-               count current )))))
+     (t (message "Cannot move up by %s rows from row %s" count
+                 current )
+        (emacspeak-auditory-icon 'warn-user)))))
 
 (defun emacspeak-table-move-down (table &optional count)
   "Move down in the table if possible."
@@ -219,8 +223,9 @@ Calls callback once per column."
     (cond
      ((< new  row-count)
       (setf (emacspeak-table-current-row table) new))
-     (t (error "Cannot move down by %s rows from row %s"
-               count current )))))
+     (t (message "Cannot move down by %s rows from row %s"
+                 count current )
+        (emacspeak-auditory-icon 'warn-user)))))
 
 (defun emacspeak-table-move-left (table &optional count)
   "Move left in the table if possible."
@@ -230,8 +235,9 @@ Calls callback once per column."
     (cond
      ((<= 0 new)
       (setf (emacspeak-table-current-column table) new))
-     (t (error "Cannot move left by %s columns from column %s"
-               count current )))))
+     (t (message "Cannot move left by %s columns from column %s"
+                 count current )
+        (emacspeak-auditory-icon 'warn-user)))))
 
 (defun emacspeak-table-move-right (table &optional count)
   "Move right in the table if possible."
@@ -242,8 +248,9 @@ Calls callback once per column."
     (cond
      ((< new  column-count)
       (setf (emacspeak-table-current-column table) new))
-     (t (error "Cannot move right by %s columns from column %s"
-               count current )))))
+     (t (message "Cannot move right by %s columns from column %s"
+                 count current )
+        (emacspeak-auditory-icon 'warn-user)))))
 
 ;;}}}
 
