@@ -1,5 +1,5 @@
 ;;; emacspeak-tetris.el --- Speech enable game of Tetris
-;;; $Id: emacspeak-tetris.el 8146 2013-02-09 20:05:08Z tv.raman.tv $
+;;; $Id$
 ;;; $Author: tv.raman.tv $ 
 ;;; Description: Auditory interface to tetris
 ;;; Keywords: Emacspeak, Speak, Spoken Output, tetris
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;; Copyright (c) 1995 -- 2011, T. V. Raman
+;;; Copyright (c) 1995 -- 2015, T. V. Raman
 ;;; All Rights Reserved. 
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -38,9 +38,16 @@
 ;;}}}
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
+;;{{{ Introduction:
+;;; Commentary:
+;;; Speech-enables tetris.
+;;; Code:
+
+;;}}}
 ;;{{{  Required modules
 
 (require 'emacspeak-preamble)
+(require 'tetris "tetris" 'no-error)
 ;;}}}
 ;;{{{  Introduction 
 
@@ -541,6 +548,14 @@ concentration and the game is a good mental challenge. "
   (or  x (setq x tetris-pos-x))
   (dtk-speak (emacspeak-tetris-get-column-contents x)))
 
+;;}}}
+;;{{{ Mode hook:
+
+(add-hook
+ 'tetris-mode-hook
+ #'(lambda ()
+     (voice-lock-mode -1)))
+
 ;;}}}
 (provide 'emacspeak-tetris)
 ;;{{{ end of file 
