@@ -1,5 +1,6 @@
-;;; emacspeak-vm.el --- Speech enable VM -- A powerful mail agent (and the one I use)
-;;; $Id: emacspeak-vm.el 9502 2014-10-25 16:19:16Z tv.raman.tv $
+;;; emacspeak-vm.el --- Speech enable VM -- A powerful mail agent
+;;;(and the one I use)
+;;; $Id$
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak extension to speech enhance vm
 ;;; Keywords: Emacspeak, VM, Email, Spoken Output, Voice annotations
@@ -16,7 +17,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;;Copyright (C) 1995 -- 2011, T. V. Raman
+;;;Copyright (C) 1995 -- 2015, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -39,13 +40,15 @@
 ;;}}}
 
 ;;{{{  Introduction:
+
+;;; Commentary:
 ;;; This module extends the mail reader vm.
 ;;; Uses voice locking for message headers and cited messages
-
+;;; Code:
 ;;}}}
 ;;{{{ requires
 (require 'emacspeak-preamble)
-
+(require  'vm "vm" 'no-error)
 ;;}}}
 ;;{{{ voice locking:
 
@@ -55,24 +58,21 @@
   :group 'vm
   :prefix "emacspeak-vm-")
 
-(defcustom emacspeak-vm-voice-lock-messages nil
+(defcustom emacspeak-vm-voice-loc nil
   "Set this to T if you want messages automatically voice locked.
 Note that some badly formed mime messages  cause trouble."
   :type 'boolean
   :group 'emacspeak-vm)
 
-(add-hook 'vm-mode-hook
-          'emacspeak-vm-mode-setup)
+(add-hook 'vm-mode-hook 'emacspeak-vm-mode-setup)
 
 (defun emacspeak-vm-mode-setup ()
   "Setup function placed on vm-mode-hook by Emacspeak."
-  (declare (special  dtk-punctuation-mode emacspeak-vm-voice-lock-messages
-                     dtk-allcaps-beep))
+  (declare (special  dtk-punctuation-mode dtk-allcaps-beep))
   (setq dtk-punctuation-mode 'all)
   (when dtk-allcaps-beep
     (dtk-toggle-allcaps-beep))
-  (emacspeak-dtk-sync)
-  (when emacspeak-vm-voice-lock-messages))
+  (emacspeak-dtk-sync) )
 
 ;;}}}
 ;;{{{ inline helpers
@@ -161,44 +161,45 @@ s(defun emacspeak-vm-yank-header ()
 
 (defun emacspeak-vm-summarize-message ()
   "Summarize the current vm message. "
-  (declare (special vm-message-pointer
-                    smtpmail-local-domain
-                    emacspeak-vm-headers-strip-octals
-                    emacspeak-vm-user-full-name emacspeak-vm-user-login-name))
+  (declare (special vm-message-pointer smtpmail-local-domain
+                    emacspeak-vm-headers-strip-octals))
   (when vm-message-pointer
     (let*  ((message (car vm-message-pointer ))
             (number (emacspeak-vm-number-of  message))
-            (from
-             (or (vm-su-full-name message) (vm-su-from message )))
+            (from (or (vm-su-full-name message) (vm-su-from message )))
             (subject (vm-su-subject message ))
-            (to
-             (or (vm-su-to-names message) (vm-su-to message )))
+            (to (or (vm-su-to-names message) (vm-su-to message )))
             (self-p
-             (or (string-match emacspeak-vm-user-full-name to)
-                 (string-match  (user-login-name) to)
-                 (string-match (format "%s@%s" (user-login-name)
-                                       smtpmail-local-domain)
-                               to)))
+             (or (string-match user-mail-address to)
+                 (string-match (user-full-name) to)
+                 (string-match  (user-login-name) to)))
             (lines (vm-su-line-count message)))
       (dtk-speak
        (vm-decode-mime-encoded-words-in-string
-        (format "%s %s %s   %s %s "
-                number
-                (or from "")
-                (if subject (format "on %s" subject) "")
-                (if (and to (< (length to) 80))
-                    (format "to %s" to) "")
-                (if lines (format "%s lines" lines) ""))))
+        (concat
+         number
+         (if from
+             (propertize from   'personality voice-brighten)
+           "")
+         (if subject
+             (propertize subject 'personality voice-lighten)
+           " ")
+         (if (and to (< (length to) 80))
+             (concat
+              (propertize " to " 'personality voice-smoothen)
+              (propertize  to 'personality voice-annotate))
+           "")
+         (if lines (format "%s lines" lines) ""))))
       (goto-char (point-min))
       (search-forward  (format "%c%c" 10 10) nil)
       (cond
        ((and self-p
              (= 0 self-p)                    ) ;mail to me and others
-        (emacspeak-auditory-icon 'item))
-       (self-p                       ;mail to others including me
+        (emacspeak-auditory-icon 'select-object))
+       (self-p                          ;mail to others including me
         (emacspeak-auditory-icon 'mark-object))
-       (t                       ;got it because of a mailing list
-        (emacspeak-auditory-icon 'select-object ))))))
+       (t                            ;got it because of a mailing list
+        (emacspeak-auditory-icon 'item ))))))
 
 (defun emacspeak-vm-speak-labels ()
   "Speak a message's labels"
@@ -245,8 +246,7 @@ s(defun emacspeak-vm-yank-header ()
 ;;}}}
 ;;{{{  Moving between messages
 
-(add-hook 'vm-select-message-hook
-          'emacspeak-vm-summarize-message)
+(add-hook 'vm-select-message-hook 'emacspeak-vm-summarize-message)
 
 ;;}}}
 ;;{{{  Scrolling messages:
@@ -285,20 +285,6 @@ Then speak the screenful. "
   (interactive)
   (emacspeak-execute-repeatedly 'forward-paragraph ))
 
-(declaim (special vm-mode-map))
-(eval-when (load)
-  (load-library "vm-vars")
-  )
-
-(declaim (special vm-mode-map))
-(define-key vm-mode-map "\M-\C-m" 'widget-button-press)
-(define-key vm-mode-map "y" 'emacspeak-vm-yank-header)
-(define-key vm-mode-map "\M-\t" 'emacspeak-vm-next-button)
-(define-key vm-mode-map  "j" 'emacspeak-hide-or-expose-all-blocks)
-(define-key vm-mode-map  "\M-g" 'vm-goto-message)
-(define-key vm-mode-map "J" 'vm-discard-cached-data)
-(define-key vm-mode-map "." 'emacspeak-vm-browse-message)
-(define-key vm-mode-map "'" 'emacspeak-speak-rest-of-buffer)
 ;;}}}
 ;;{{{  deleting and killing
 
@@ -395,17 +381,26 @@ Then speak the screenful. "
 
 ;;}}}
 ;;{{{  Keybindings:
-(declaim  (special vm-mode-map
-                   global-map
-                   emacspeak-prefix
-                   emacspeak-keymap))
-(define-key vm-mode-map "\M-c" 'emacspeak-vm-catch-up-all-messages)
-(define-key vm-mode-map "\M-j" 'emacspeak-vm-locate-subject-line)
-(define-key vm-mode-map "," 'emacspeak-vm-speak-message)
-(define-key vm-mode-map "\M-l" 'emacspeak-vm-speak-labels)
-(define-key vm-mode-map
-  (concat emacspeak-prefix "m")
-  'emacspeak-vm-mode-line)
+(when (boundp 'vm-mode-map)
+  (declaim  (special
+             vm-mode-map
+             global-map emacspeak-prefix emacspeak-keymap))
+  (define-key vm-mode-map "\M-\C-m" 'widget-button-press)
+  (define-key vm-mode-map "y" 'emacspeak-vm-yank-header)
+  (define-key vm-mode-map "\M-\t" 'emacspeak-vm-next-button)
+  (define-key vm-mode-map  "j" 'emacspeak-hide-or-expose-all-blocks)
+  (define-key vm-mode-map  "\M-g" 'vm-goto-message)
+  (define-key vm-mode-map "J" 'vm-discard-cached-data)
+  (define-key vm-mode-map "." 'emacspeak-vm-browse-message)
+  (define-key vm-mode-map "'" 'emacspeak-speak-rest-of-buffer)
+  (define-key vm-mode-map "\M-c" 'emacspeak-vm-catch-up-all-messages)
+  (define-key vm-mode-map "\M-j" 'emacspeak-vm-locate-subject-line)
+  (define-key vm-mode-map "," 'emacspeak-vm-speak-message)
+  (define-key vm-mode-map "\M-l" 'emacspeak-vm-speak-labels)
+  (define-key vm-mode-map
+    (concat emacspeak-prefix "m")
+    'emacspeak-vm-mode-line)
+  )
 ;;}}}
 ;;{{{ advise searching:
 (defadvice vm-isearch-forward (around emacspeak pre act comp)
@@ -487,34 +482,35 @@ Leave point at front of decoded attachment."
 (add-hook 'vm-presentation-mode-hook
           #'(lambda nil
               (emacspeak-pronounce-refresh-pronunciations)))
-(declaim (special emacspeak-pronounce-internet-smileys-pronunciations))
-(loop for hook in
-      (list 'mail-mode-hook
-            'vm-presentation-mode-hook)
-      do
-      (add-hook hook 'emacspeak-pronounce-refresh-pronunciations
-                'append ))
 
-(loop for mode in
-      '(vm-presentation-mode
-        mail-mode)
-      do
-      (emacspeak-pronounce-augment-pronunciations mode
-                                                  emacspeak-pronounce-internet-smileys-pronunciations)
-      (emacspeak-pronounce-add-dictionary-entry mode
-                                                emacspeak-speak-embedded-url-pattern
-                                                (cons 're-search-forward
-                                                      #'(lambda
-                                                          (url) "
-      Link ")))
-      (emacspeak-pronounce-add-dictionary-entry mode
-                                                emacspeak-speak-rfc-3339-datetime-pattern
-                                                (cons 're-search-forward
-                                                      'emacspeak-speak-decode-rfc-3339-datetime))
-      (emacspeak-pronounce-add-dictionary-entry mode
-                                                emacspeak-speak-iso-datetime-pattern
-                                                (cons 're-search-forward
-                                                      'emacspeak-speak-decode-iso-datetime)))
+(declaim (special emacspeak-pronounce-internet-smileys-pronunciations))
+(loop
+ for hook in
+ '(mail-mode-hook vm-presentation-mode-hook)
+ do
+ (add-hook hook 'emacspeak-pronounce-refresh-pronunciations 'append ))
+
+(loop
+ for mode in
+ '(vm-presentation-mode mail-mode)
+ do
+ (emacspeak-pronounce-augment-pronunciations
+  mode
+  emacspeak-pronounce-internet-smileys-pronunciations)
+ (emacspeak-pronounce-add-dictionary-entry
+  mode
+  emacspeak-speak-embedded-url-pattern
+  (cons
+   're-search-forward
+   #'(lambda (url) " Link ")))
+ (emacspeak-pronounce-add-dictionary-entry
+  mode
+  emacspeak-speak-rfc-3339-datetime-pattern
+  (cons 're-search-forward 'emacspeak-speak-decode-rfc-3339-datetime))
+ (emacspeak-pronounce-add-dictionary-entry
+  mode
+  emacspeak-speak-iso-datetime-pattern
+  (cons 're-search-forward 'emacspeak-speak-decode-iso-datetime)))
 
 ;;}}}
 ;;{{{ advice button motion
@@ -555,7 +551,9 @@ If N is negative, move backward instead."
       (when (and backward (not (get-text-property (point) 'w3-hyperlink-info)))
         (goto-char (funcall function (point) 'w3-hyperlink-info nil limit)))
       ;; Skip past intangible buttons.
-      (when (get-text-property (point) 'intangible)
+      (when
+          (or (get-text-property (point) 'intangible)
+              (get-text-property (point) 'cursorintangible))
         (incf n))
       (decf n))
     (unless (zerop n)
@@ -566,6 +564,34 @@ If N is negative, move backward instead."
 ;;{{{ saving mime attachment under point
 
 ;;}}}
+;;{{{ Voice Lock:
+
+(when (locate-library "u-vm-color")
+  (require 'u-vm-color)
+  (voice-setup-add-map
+   '(
+     (u-vm-color-author-face voice-brighten)
+     (u-vm-color-citation-1-face voice-smoothen)
+     (u-vm-color-citation-2-face voice-smoothen-extra)
+     (u-vm-color-date-face voice-monotone-medium)
+     (u-vm-color-header-face voice-bolden-medium)
+     (u-vm-color-recipient-face voice-annotate)
+     (u-vm-color-signature-face voice-smoothen)
+     (u-vm-color-spamassassin-face voice-monotone)
+     (u-vm-color-subject-face voice-lighten)
+     (u-vm-color-time-face voice-monotone)
+     (u-vm-color-user-face voice-animate)
+
+     )
+   )
+  (add-hook 'vm-showing-message-hook #'u-vm-color-fontify-buffer)
+  (add-hook 'vm-presentation-mode-hook #'u-vm-color-fontify-buffer)
+  (add-hook 'vm-summary-mode-hook #'u-vm-color-summary-mode)
+  (add-hook 'vm-select-message-hook #'u-vm-color-fontify-buffer)
+  )
+
+;;}}}
+
 ;;{{{ configure and customize vm
 
 ;;; This is how I customize VM
@@ -596,8 +622,7 @@ Emacspeak."
             vm-delete-after-saving
             vm-url-browser
             vm-confirm-new-folders
-            vm-move-after-deleting
-            emacspeak-vm-voice-lock-messages))
+            vm-move-after-deleting))
   (setq vm-mime-charset-converter-alist
         '(
           ("utf-8" "iso-8859-1" "iconv -f utf-8 -t iso-8859-1")
@@ -620,8 +645,7 @@ Emacspeak."
         vm-delete-after-saving t
         vm-url-browser 'browse-url
         vm-confirm-new-folders t
-        vm-move-after-deleting nil
-        emacspeak-vm-voice-lock-messages t)
+        vm-move-after-deleting nil)
   t)
 
 (when emacspeak-vm-use-raman-settings
@@ -667,15 +691,15 @@ text using wvText."
   :type 'string
   :group 'emacspeak-vm)
 
-(defsubst emacspeak-vm-add-mime-convertor (convertor)
-  "Helper to add a convertor specification."
+(defun emacspeak-vm-add-mime-converter (converter)
+  "Helper to add a converter specification."
   (declare (special vm-mime-type-converter-alist))
   (unless
       (find-if
        #'(lambda  (i)
-           (string-equal (car i) (car convertor)))
+           (string-equal (car i) (car converter)))
        vm-mime-type-converter-alist)
-    (push   convertor
+    (push   converter
             vm-mime-type-converter-alist)))
 
 (defun emacspeak-vm-customize-mime-settings ()
@@ -695,29 +719,30 @@ text using wvText."
                     emacspeak-vm-xls2html
                     emacspeak-vm-doc2text
                     emacspeak-vm-cal2text))
-  (emacspeak-vm-add-mime-convertor
+  (emacspeak-vm-add-mime-converter
    (list "text/calendar" "text/plain" emacspeak-vm-cal2text))
-  (emacspeak-vm-add-mime-convertor
+  (emacspeak-vm-add-mime-converter
    (list "application/pdf" "text/plain"
          emacspeak-vm-pdf2text))
-  (emacspeak-vm-add-mime-convertor
+  (emacspeak-vm-add-mime-converter
    (list "application/vnd.ms-excel" "text/html"
          emacspeak-vm-xls2html))
-  (emacspeak-vm-add-mime-convertor
+  (emacspeak-vm-add-mime-converter
    (list "application/vnd.ms-powerpoint" "text/html" emacspeak-vm-ppt2html))
-  (emacspeak-vm-add-mime-convertor
+  (emacspeak-vm-add-mime-converter
    (list "application/msword" "text/plain" emacspeak-vm-doc2text))
   (setq vm-preview-lines nil
         vm-infer-mime-types t
         vm-mime-decode-for-preview nil
         vm-auto-decode-mime-messages t
         vm-auto-displayed-mime-content-type-exceptions '("text/html")
-        vm-mime-attachment-save-directory (expand-file-name "~/Mail/attachments/")
+        vm-mime-attachment-save-directory
+        (expand-file-name "~/Mail/attachments/")
         vm-mime-base64-encoder-program "base64-encode"
         vm-mime-base64-decoder-program "base64-decode")
   t)
 
-(when emacspeak-vm-customize-mime-settings
+(when (and (featurep 'vm )emacspeak-vm-customize-mime-settings)
   (emacspeak-vm-customize-mime-settings))
 
 ;;}}}
