@@ -1,5 +1,5 @@
 ;;; emacspeak-w3.el --- Speech enable W3 WWW browser -- includes ACSS Support
-;;; $Id: emacspeak-w3.el 9072 2014-04-16 15:27:01Z tv.raman.tv $
+;;; $Id$
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak enhancements for W3
 ;;; Keywords: Emacspeak, W3, WWW
@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2011, T. V. Raman
+;;;Copyright (C) 1995 -- 2015, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -150,51 +150,53 @@
   (when (locate-library
          "w3-imenu")
     (require 'w3-imenu))
-  (loop for binding in
-        '(
-          ( "\C-t" emacspeak-google-command)
-          ("'" emacspeak-speak-rest-of-buffer)
-          ("\"" emacspeak-speak-skim-buffer)
-          ("/" search-forward)
-          ("?" emacspeak-webutils-google-similar-to-this-page)
-          (":" emacspeak-w3-speak-this-element)
-          ("J" w3-table-move-to-next-table-row)
-          ("K" w3-table-move-to-previous-table-row)
-          ("L" w3-table-move-to-next-table-column)
-          ("H" w3-table-move-to-previous-table-column)
-          ("\;" emacspeak-speak-face-interval-and-move)
-          ("A" emacspeak-feeds-atom-display)
-          ("F" emacspeak-webutils-fv)
-          ("X" emacspeak-xslt-view-xml)
-          ("C" emacspeak-webutils-google-extract-from-cache)
-          ("\M-l" emacspeak-w3-lynx-url-under-point)
-          ("N" emacspeak-speak-next-personality-chunk)
-          ("P" emacspeak-speak-previous-personality-chunk)
-          ("o" emacspeak-wizards-next-bullet)
-          ("O" emacspeak-wizards-previous-bullet)
-          ("R" emacspeak-feeds-rss-display)
-          ("\C-f" w3-table-focus-on-this-cell)
-          ("\M- " emacspeak-imenu-speak-this-section)
-          ("\M-n" emacspeak-imenu-goto-next-index-position)
-          ("\M-p" emacspeak-imenu-goto-previous-index-position)
-          ("\M-;" emacspeak-webutils-play-media-at-point)
-          ("\M-s" emacspeak-w3-jump-to-submit)
-          ("c" emacspeak-w3-curl-url-under-point)
-          ("e" emacspeak-we-xsl-map)
-          ("g" emacspeak-webutils-google-on-this-site)
-          ("hh" emacspeak-w3-show-http-headers)
-          ("i" emacspeak-w3-next-parsed-item)
-          ("j" imenu)
-          ("l" emacspeak-webutils-google-who-links-to-this-page)
-          ("n" emacspeak-w3-next-doc-element)
-          ("p" emacspeak-w3-previous-doc-element)
-          ("t" emacspeak-webutils-transcode-via-google)
-          ("T"  emacspeak-webutils-jump-to-title-in-content)
-          ("y" emacspeak-we-url-rewrite-and-follow)
-          ("z" emacspeak-w3-speak-next-block)
-          ([C-Return] emacspeak-webutils-open-in-other-browser))
-        do
-        (emacspeak-keymap-update w3-mode-map binding))
+  (loop
+   for binding in
+   '(
+     ("'" emacspeak-speak-rest-of-buffer)
+     ("/" search-forward)
+     (":" emacspeak-w3-speak-this-element)
+     ("?" emacspeak-webutils-google-similar-to-this-page)
+     ("A" emacspeak-feeds-atom-display)
+     ("C" emacspeak-webutils-google-extract-from-cache)
+     ("C-RET" emacspeak-webutils-open-in-other-browser)
+     ("C-f" w3-table-focus-on-this-cell)
+     ("C-t" emacspeak-google-command)
+     ("F" emacspeak-webutils-fv)
+     ("H" w3-table-move-to-previous-table-column)
+     ("J" w3-table-move-to-next-table-row)
+     ("K" w3-table-move-to-previous-table-row)
+     ("L" w3-table-move-to-next-table-column)
+     ("M-;" emacspeak-webutils-play-media-at-point)
+     ("M-SPC" emacspeak-imenu-speak-this-section)
+     ("M-l" emacspeak-w3-lynx-url-under-point)
+     ("M-n" emacspeak-imenu-goto-next-index-position)
+     ("M-p" emacspeak-imenu-goto-previous-index-position)
+     ("M-s" emacspeak-w3-jump-to-submit)
+     ("N" emacspeak-speak-next-personality-chunk)
+     ("O" emacspeak-wizards-previous-bullet)
+     ("P" emacspeak-speak-previous-personality-chunk)
+     ("R" emacspeak-feeds-rss-display)
+     ("T"  emacspeak-webutils-jump-to-title-in-content)
+     ("X" emacspeak-xslt-view-xml)
+     ("\"" emacspeak-speak-skim-buffer)
+     ("\;" emacspeak-speak-face-interval-and-move)
+     ("c" emacspeak-w3-curl-url-under-point)
+     ("e" emacspeak-we-xsl-map)
+     ("g" emacspeak-webutils-google-on-this-site)
+     ("hh" emacspeak-w3-show-http-headers)
+     ("i" emacspeak-w3-next-parsed-item)
+     ("j" imenu)
+     ("l" emacspeak-webutils-google-who-links-to-this-page)
+     ("n" emacspeak-w3-next-doc-element)
+     ("o" emacspeak-wizards-next-bullet)
+     ("p" emacspeak-w3-previous-doc-element)
+     ("t" emacspeak-webutils-transcode-via-google)
+     ("y" emacspeak-we-url-rewrite-and-follow)
+     ("z" emacspeak-w3-speak-next-block)
+     )
+   do
+   (emacspeak-keymap-update w3-mode-map binding))
   (w3-masquerade-stub 1 "Mozilla" "5.0"))
 
 (add-hook 'w3-load-hook 'emacspeak-w3-load-hook)
@@ -346,7 +348,7 @@ document is displayed in a separate buffer. "
 (defun emacspeak-w3-next-doc-element (&optional count)
   "Move forward  to the next document element.
 Optional interactive prefix argument COUNT
-specifies by how many eleemnts to move."
+specifies by how many elements to move."
   (interactive "P")
   (cond
    ((null count)
@@ -370,7 +372,7 @@ implemented. ")))
 (defun emacspeak-w3-previous-doc-element (&optional count)
   "Move back  to the previous document element.
 Optional interactive prefix argument COUNT
-specifies by how many eleemnts to move."
+specifies by how many elements to move."
   (interactive "P")
   (cond
    ((null count)
@@ -518,7 +520,7 @@ element. "
       (setq emacspeak-we-url-rewrite-rule rule))))
 
 ;;}}}
-;;{{{ fix bug in W3 under emacs 21
+;;{{{ fix bug in W3 under newer emacsuns
 
 (defadvice w3-nasty-disgusting-http-equiv-handling (around fix-bug pre act comp)
   (let ((emacspeak-use-auditory-icons nil))
@@ -537,17 +539,11 @@ element. "
   "silence spoken messages."
   (let ((emacspeak-speak-messages nil))
     ad-do-it))
-
-;; (defadvice url-http-wait-for-headers-change-function
-;;   (around emacspeak pre act comp)
-;;   "silence spoken messages."
-;;   (let ((emacspeak-speak-messages nil))
-;;     ad-do-it))
-
 ;;}}}
 ;;{{{ backward compatibility
 
 ;;; this will go away
+;;; It's only used in w3-speak.el but that module is frozen for now
 (defalias 'make-dtk-speech-style 'make-acss)
 (defalias 'dtk-personality-from-speech-style 'acss-personality-from-speech-style)
 
@@ -716,20 +712,21 @@ HTML."
     (emacspeak-we-build-id-cache)
     (emacspeak-we-build-class-cache)
     (emacspeak-we-build-role-cache))
-  (when (and emacspeak-we-xsl-p
-             emacspeak-we-xsl-transform
-             (not  (string-match "temp" (buffer-name))))
+  (cond
+   (emacspeak-web-pre-process-hook (emacspeak-webutils-run-pre-process-hook))
+   ((and emacspeak-we-xsl-p
+         emacspeak-we-xsl-transform
+         (not  (string-match "temp" (buffer-name))))
     (emacspeak-xslt-region
      emacspeak-we-xsl-transform
-     (point-min)
-     (point-max)
+     (point-min) (point-max)
      emacspeak-we-xsl-params)
     (emacspeak-we-build-id-cache)
     (emacspeak-we-build-class-cache)
     (when emacspeak-we-xsl-keep-result
       (clone-buffer
        (format "xslt-%s"
-               (buffer-name))))))
+               (buffer-name)))))))
 
 ;;}}}
 ;;{{{ fix css bug:
