@@ -1,5 +1,5 @@
 ;;; emacspeak-websearch.el --- search utilities
-;;; $Id: emacspeak-websearch.el 9540 2014-11-11 22:09:50Z tv.raman.tv $
+;;; $Id$
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak extension to make Web searching convenient
 ;;; Keywords: Emacspeak, WWW interaction
@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2011, T. V. Raman
+;;;Copyright (C) 1995 -- 2015, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -58,8 +58,10 @@
 
 ;;}}}
 ;;{{{ Forward Declarations:
+(defvar emacspeak-websearch-curl-program
+  (executable-find "curl")
+  "Curl executable.")
 
-(defvar emacspeak-xslt-directory)
 (defvar emacspeak-wizards-personal-portfolio)
 
 (declare-function gweb-google-autocomplete (&optional prompt))
@@ -182,44 +184,6 @@ When using supported browsers,  this interface attempts to speak the most releva
 ;;}}}
 ;;{{{ websearch utilities
 
-;;{{{ display form
-
-(emacspeak-websearch-set-searcher 'display-form
-                                  'emacspeak-websearch-display-form)
-
-(emacspeak-websearch-set-key ?/ 'display-form)
-
-(defun emacspeak-websearch-display-form (form-markup)
-  "Display form specified by form-markup."
-  (interactive
-   (list
-    (let ((emacspeak-speak-messages nil))
-      (emacspeak-pronounce-define-local-pronunciation
-       (expand-file-name "xml-forms"
-                         emacspeak-lisp-directory)
-       " xml forms ")
-      (read-file-name "Display Form: "
-                      (expand-file-name "xml-forms/" emacspeak-lisp-directory)))))
-  (declare (special emacspeak-we-xsl-p
-                    emacspeak-web-post-process-hook
-                    emacspeak-lisp-directory))
-  (let ((buffer (get-buffer-create " *search-form*"))
-        (emacspeak-we-xsl-p nil))
-    (save-excursion
-      (set-buffer buffer)
-      (erase-buffer)
-      (kill-all-local-variables)
-      (insert-file-contents  form-markup)
-      (add-hook 'emacspeak-web-post-process-hook
-                #'(lambda ()
-                    (goto-char (point-min))
-                    (widget-forward 1)
-                    (emacspeak-auditory-icon 'open-object)
-                    (emacspeak-widget-summarize (widget-at (point)))))
-      (browse-url-of-buffer)
-      (kill-buffer buffer))))
-
-;;}}}
 ;;{{{ Computer Science Bibliography
 
 (emacspeak-websearch-set-searcher 'biblio
@@ -298,29 +262,6 @@ When using supported browsers,  this interface attempts to speak the most releva
      ((char-equal ?c type-char)
       (emacspeak-webutils-post-process "citations found" 'emacspeak-speak-line)))))
 
-;;}}}
-;;{{{ BlinkX
-
-(emacspeak-websearch-set-searcher 'blinkx
-                                  'emacspeak-websearch-blinkx-search)
-
-(emacspeak-websearch-set-key ?B 'blinkx)
-
-(defvar emacspeak-websearch-blinkx-uri
-  "http://emea-store.blinkx.com/redirectors/SmartFeed.php?max=50&channel=reuters+revs+fox+webvideo+theonenetwork+verdictoncars+londontv+totalvid+inthebox+transmission+ifilms2+cspan+cspan2+bbcxml+bloomberg+cnn+itv+msnbc+forbes+podcast&siteId=3&oId=2100-1032-5793745&ontId=1023&lop=nl.ex&q="
-  "URI to search  BlinkX for broadcasts.")
-
-;;;###autoload
-(defun emacspeak-websearch-blinkx-search (query)
-  "BlinkX RSS Generator."
-  (interactive
-   (list
-    (emacspeak-websearch-read-query "Search Online Broadcasts for: ")))
-  (declare (special emacspeak-websearch-blinkx-uri))
-  (emacspeak-feeds-rss-display
-   (concat  emacspeak-websearch-blinkx-uri
-            (emacspeak-url-encode query))))
-
 ;;}}}
 ;;{{{ FolDoc
 
@@ -329,7 +270,7 @@ When using supported browsers,  this interface attempts to speak the most releva
 (emacspeak-websearch-set-key ?f 'foldoc)
 
 (defvar emacspeak-websearch-foldoc-uri
-  "http://wombat.doc.ic.ac.uk/foldoc/"
+  "http://foldoc.org/"
   "*URI for launching a FolDoc  search.")
 
 ;;;###autoload
@@ -346,76 +287,6 @@ When using supported browsers,  this interface attempts to speak the most releva
    query
    'emacspeak-speak-line))
 
-;;}}}
-;;{{{ quotes from yahoo
-
-(emacspeak-websearch-set-searcher 'quotes-yahoo
-                                  'emacspeak-websearch-quotes-yahoo-search)
-
-(emacspeak-websearch-set-key ?q 'quotes-yahoo)
-
-(defvar emacspeak-websearch-quotes-yahoo-uri
-  "http://finance.yahoo.com/q?s="
-  "*URI for launching a Yahoo Quotes  search.")
-
-(defvar emacspeak-websearch-quotes-csv-yahoo-uri
-  "http://quote.yahoo.com/d/quotes.csv?f=snl1d1t1c1p2va2bapomwerr1dyj1x&s="
-  "*URI for launching a Yahoo Quotes  search.
-See http://www.gummy-stuff.org/Yahoo-data.htm and Perl module Finance::Yahoo")
-
-(defvar emacspeak-websearch-quotes-yahoo-options
-  "&d=v1"
-  "*Additional default options to pass to Yahoo.")
-
-(defvar emacspeak-websearch-curl-program "curl"
-  "Name of curl executable")
-
-;;;###autoload
-(defun emacspeak-websearch-quotes-yahoo-search (query &optional prefix)
-  "Perform a Quotes Yahoo .
-Default tickers to look up is taken from variable
-emacspeak-wizards-personal-portfolio.
-Default is to present the data in emacspeak's table browsing
-mode --optional interactive prefix arg
-causes data to be displayed as  a Web page.
-You can customize the defaults by setting variable
-emacspeak-websearch-quotes-yahoo-options to an appropriate string."
-  (interactive
-   (list
-    (emacspeak-websearch-read-query "Lookup quotes: "
-                                    emacspeak-wizards-personal-portfolio
-                                    emacspeak-wizards-personal-portfolio)
-    current-prefix-arg))
-  (declare (special emacspeak-websearch-quotes-yahoo-uri
-                    emacspeak-wizards-personal-portfolio
-                    emacspeak-websearch-quotes-yahoo-options
-                    emacspeak-websearch-curl-program
-                    emacspeak-websearch-quotes-csv-yahoo-uri))
-  (cond
-   ((null prefix)
-    (let ((uri (concat emacspeak-websearch-quotes-csv-yahoo-uri
-                       (emacspeak-url-encode (format "%s" query))))
-          (results "*quotes-table*")
-          (process nil))
-;;; nuke old results if any
-      (when (get-buffer results )
-        (kill-buffer results))
-      (setq process
-            (start-process   "lynx"
-                             results
-                             emacspeak-websearch-curl-program
-                             "--silent"
-                             uri))
-      (set-process-sentinel process 'emacspeak-websearch-view-csv-data)))
-   (t
-    (browse-url
-     (concat emacspeak-websearch-quotes-yahoo-uri
-             (emacspeak-url-encode query)
-             emacspeak-websearch-quotes-yahoo-options))
-    (emacspeak-webutils-post-process
-     "Symbol"
-     'emacspeak-speak-line))))
-
 ;;}}}
 ;;{{{ Lookup company news at Yahoo
 
@@ -555,22 +426,6 @@ Optional second arg as-html processes the results as HTML rather than data."
          "Open"
          'emacspeak-speak-line)))))
 
-;;}}}
-;;{{{  usenet
-
-(emacspeak-websearch-set-searcher 'dejanews
-                                  'emacspeak-websearch-usenet-search)
-
-(emacspeak-websearch-set-key ?D 'dejanews)
-
-;;;###autoload
-(defun emacspeak-websearch-usenet-search (group)
-  "Search a Usenet newsgroup."
-  (interactive
-   (list
-    (read-from-minibuffer "Newsgroup search: ")))
-  (emacspeak-websearch-usenet group 'search))
-
 ;;}}}
 ;;{{{ source forge
 
@@ -598,24 +453,6 @@ Optional second arg as-html processes the results as HTML rather than data."
                                         "&words="
                                         (emacspeak-url-encode query))))
 
-(defvar emacspeak-websearch-freshmeat-search-uri
-  "http://www.freshmeat.net/search?q="
-  "URI for searching Freshmeat site. ")
-
-;;;###autoload
-(defun emacspeak-websearch-freshmeat-search (query)
-  "Search Freshmeat  Site. "
-  (interactive
-   (list
-    (emacspeak-websearch-read-query "Search Freshmeat  for: ")))
-  (declare (special emacspeak-websearch-freshmeat-search-uri))
-  (browse-url
-   (concat emacspeak-websearch-freshmeat-search-uri
-           (emacspeak-url-encode query)))
-  (emacspeak-webutils-post-process
-   "search results"
-   'emacspeak-speak-line))
-
 (defvar emacspeak-websearch-ctan-search-uri
   "http://www.ctan.org/tools/filesearch?action=/search/&filename="
   "URI for searching CTAN archives for tex and latex utilities. ")
@@ -653,27 +490,9 @@ Optional second arg as-html processes the results as HTML rather than data."
   (emacspeak-webutils-post-process
    query
    'emacspeak-speak-line))
-(defvar emacspeak-websearch-swik-search-uri
-  "http://www.swik.net/project/"
-  "URI for locating project communities via swik.")
-
-;;;###autoload
-(defun emacspeak-websearch-swik-search (query)
-  "Search swik software community site."
-  (interactive
-   (list
-    (emacspeak-websearch-read-query
-     "SWIK Query:")))
-  (declare (special emacspeak-websearch-swik-search-uri))
-  (browse-url
-   (concat emacspeak-websearch-swik-search-uri
-           (emacspeak-url-encode query)))
-  (emacspeak-webutils-post-process
-   query
-   'emacspeak-speak-line))
 
 (defvar emacspeak-websearch-software-sites
-  "f FreshMeat p Perl s SourceForge t TEX cap S SWIK"
+  "p Perl s SourceForge t TEX cap"
   "Sites searched for open source software. ")
 
 ;;; top level dispatcher for searching source locations
@@ -685,11 +504,9 @@ Optional second arg as-html processes the results as HTML rather than data."
   (let ((site
          (read-char emacspeak-websearch-software-sites)))
     (case site
-      (?f (call-interactively 'emacspeak-websearch-freshmeat-search))
       (?p (call-interactively 'emacspeak-websearch-cpan-search))
       (?s (call-interactively 'emacspeak-websearch-sourceforge-search))
       (?t (call-interactively 'emacspeak-websearch-ctan-search))
-      (?S (call-interactively 'emacspeak-websearch-swik-search))
       (otherwise (message emacspeak-websearch-software-sites )))))
 
 ;;}}}
@@ -736,17 +553,14 @@ Optional second arg as-html processes the results as HTML rather than data."
 (emacspeak-websearch-set-searcher 'google
                                   'emacspeak-websearch-google)
 (emacspeak-websearch-set-key ?g 'google)
-(emacspeak-websearch-set-key ?i 'google)
-
+(emacspeak-websearch-set-key ?i 'google-with-toolbelt)
+(emacspeak-websearch-set-searcher 'google-with-toolbelt
+                                  'emacspeak-websearch-google-with-toolbelt)
 ;;;###autoload
 (defcustom emacspeak-websearch-google-number-of-results 25
   "Number of results to return from google search."
   :type 'number
   :group 'emacspeak-websearch)
-(defcustom emacspeak-websearch-google-results-only t
-  "Specify if we show just results or the complete Google page."
-  :type  'boolean
-  :group 'emacspeak-websearch)
 
 (defvar emacspeak-websearch-google-uri-template
   "www.google.com/search?source=hp&q="
@@ -776,51 +590,40 @@ Optional second arg as-html processes the results as HTML rather than data."
 
 ;;;###autoload
 (defun emacspeak-websearch-google (query &optional flag)
-  "Perform a Google search.
-First optional interactive prefix arg `flag' prompts for
-additional search options. Second interactive prefix arg is
-equivalent to hitting the I'm Feeling Lucky button on
-Google. Uses customizable option
-`emacspeak-websearch-google-results-only' to determine if we show
-just results."
-  (interactive
-   (list
-    (gweb-google-autocomplete)
-    current-prefix-arg))
+  "Perform a Google search.  First optional interactive prefix arg
+`flag' prompts for additional search options. Second interactive
+prefix arg is equivalent to hitting the I'm Feeling Lucky button on Google. "
+  (interactive (list (gweb-google-autocomplete) current-prefix-arg))
   (declare (special emacspeak-google-query emacspeak-google-toolbelt
-                    emacspeak-websearch-google-results-only
                     emacspeak-websearch-google-options emacspeak-websearch-google-number-of-results))
   (setq emacspeak-google-toolbelt nil)
-  (let ((toolbelt (emacspeak-google-toolbelt))
-        (add-toolbelt (and flag  (listp flag) (= 4 (car flag))))
-        (lucky (and flag  (listp flag) (= 16 (car flag)))))
+  (lexical-let ((toolbelt (emacspeak-google-toolbelt))
+                (search-url nil)
+                (add-toolbelt (and flag  (consp flag) (= 4 (car flag))))
+                (lucky (and flag  (consp flag) (= 16 (car flag)))))
     (emacspeak-webutils-cache-google-query query)
     (emacspeak-webutils-cache-google-toolbelt toolbelt)
     (if lucky
         (emacspeak-webutils-autospeak)
       (emacspeak-webutils-post-process "Results" 'emacspeak-speak-line))
-    (let ((search-url
-           (concat
-            (emacspeak-websearch-google-uri)
-            query
-            (format "&num=%s%s"         ; acumulate options
-                    emacspeak-websearch-google-number-of-results
-                    (or emacspeak-websearch-google-options ""))
-            (when lucky
-              (concat
-               "&btnI="
-               (emacspeak-url-encode "I'm Feeling Lucky"))))))
-      (cond
-       (add-toolbelt (emacspeak-google-toolbelt-change))
-       (lucky (browse-url search-url))
-       (emacspeak-websearch-google-results-only
-        (emacspeak-we-extract-by-id-list
-         '( "rhs" "center_col" "nav")
-         search-url 'speak))
-       (t (emacspeak-webutils-with-xsl-environment
-           (expand-file-name "default.xsl" emacspeak-xslt-directory)
-           nil emacspeak-xslt-options
-           (browse-url search-url)))))))
+    (setq search-url
+          (concat
+           (emacspeak-websearch-google-uri)
+           query
+           (format "&num=%s%s"          ; acumulate options
+                   emacspeak-websearch-google-number-of-results
+                   (or emacspeak-websearch-google-options ""))
+           (when lucky
+             (concat
+              "&btnI="
+              (emacspeak-url-encode "I'm Feeling Lucky")))))
+    (cond
+     (add-toolbelt (emacspeak-google-toolbelt-change))
+     (lucky (browse-url search-url))
+     (t                                 ; always just show results
+      (emacspeak-we-extract-by-id-list
+       '( "rhs" "center_col" "nav")
+       search-url 'speak)))))
 
 ;;{{{ IMFA
 
@@ -831,7 +634,8 @@ just results."
 ;;}}}
 
 (defvar emacspeak-websearch-accessible-google-url
-  "https://www.google.com/search?esrch=SearchLite::OptIn&site=&q=%s&num=25&gbv=1&sei=L8kNVI_kKJWpyATPv4Aw"
+                                        ;"https://www.google.com/search?esrch=SearchLite::OptIn&site=&q=%s&num=25&gbv=1&sei=L8kNVI_kKJWpyATPv4Aw"
+  "https://www.google.com/search?num=25&lite=90586&q=%s"
   "Using experimental Google Lite.")
 
 ;;;###autoload
@@ -855,6 +659,11 @@ Optional prefix arg prompts for toolbelt options."
          (format emacspeak-websearch-accessible-google-url query)
          'speak)))))
 
+;;;###autoload
+(defun emacspeak-websearch-google-with-toolbelt (query)
+  "Launch Google search with toolbelt."
+  (interactive (list (gweb-google-autocomplete "AGoogle: ")))
+  (funcall-interactively #'emacspeak-websearch-accessible-google query 'use-toolbelt))
 (emacspeak-websearch-set-searcher 'google-lucky
                                   'emacspeak-websearch-google-feeling-lucky)
 
@@ -910,110 +719,6 @@ https://www.google.com/options/specialsearches.html "
   (define-key calendar-mode-map "gg"
     'emacspeak-websearch-google-search-in-date-range))
 
-;;}}}
-;;{{{ Google Swiss Army Knife:
-(emacspeak-websearch-set-searcher 'google-sak
-                                  'emacspeak-websearch-google-sak)
-
-(emacspeak-websearch-set-key ?\' 'google-sak )
-(defvar emacspeak-websearch-google-images
-  "http://images.google.com/images?hl=en&ie=UTF-8&q="
-  "URI for Google Image Search.")
-
-(defvar emacspeak-websearch-google-news-uri
-  "http://groups.google.com/grphp?hl=en&ie=UTF-8&q="
-  "URI for Google News search.")
-
-(defvar emacspeak-websearch-froogle-uri
-  "http://froogle.google.com/frghp?hl=en&ie=UTF-8&q="
-  "URI for Google Froogle.")
-(defvar emacspeak-websearch-google-html-maps-uri
-  "http://maps.google.com/?output=html&hl=en&ie=UTF-8&f=q&q="
-  "URI for Google Maps using plain HTML.")
-
-(defvar emacspeak-websearch-google-scholar-uri
-  "http://scholar.google.com/scholar?ie=UTF-8&oe=UTF-8&hl=en&num=25&q="
-  "URI for Google Scholar search.")
-
-(defvar emacspeak-websearch-google-books-uri
-  "http://books.google.com/books?btnG=Search+Books&hl=en&q="
-  "URI for Google Book Search.")
-
-(defvar emacspeak-websearch-google-videos-uri
-  "http://video.google.com/videofeed?type=search&q="
-  "URI for Google Video search.")
-
-(defvar emacspeak-websearch-google-launch-uris
-  (list
-   (cons 'web (emacspeak-websearch-google-uri))
-   (cons 'images  emacspeak-websearch-google-images)
-   (cons 'news emacspeak-websearch-google-news-uri)
-   (cons 'froogle emacspeak-websearch-froogle-uri)
-   (cons 'books emacspeak-websearch-google-books-uri)
-   (cons 'scholar emacspeak-websearch-google-scholar-uri)
-   (cons 'maps emacspeak-websearch-google-html-maps-uri)
-   (cons 'videos emacspeak-websearch-google-videos-uri))
-  "Association list of Google search URIs.")
-
-;;;###autoload
-(defun emacspeak-websearch-google-sak(engine query)
-  "Perform a Google query against a specific index."
-  (interactive
-   (list
-    (completing-read "Engine: "
-                     emacspeak-websearch-google-launch-uris)
-    (gweb-google-autocomplete "Google for: ")))
-  (declare (special emacspeak-websearch-read-query))
-  (browse-url
-   (concat (cdr (assq engine
-                      emacspeak-websearch-google-launch-uris))
-           (emacspeak-url-encode query))))
-
-;;}}}
-;;{{{ google advanced search
-
-(emacspeak-websearch-set-searcher 'google-advanced
-                                  'emacspeak-websearch-google-advanced)
-
-(emacspeak-websearch-set-key ?. 'google-advanced)
-
-(defvar emacspeak-websearch-google-advanced-form
-  (expand-file-name "xml-forms/google-advanced.xml"
-                    emacspeak-lisp-directory)
-  "Markup for Google advanced search form.")
-
-;;;###autoload
-(defun emacspeak-websearch-google-advanced ()
-  "Present Google advanced search form simplified for speech interaction."
-  (interactive)
-  (declare (special emacspeak-websearch-google-advanced-form))
-  (emacspeak-websearch-display-form emacspeak-websearch-google-advanced-form))
-
-;;}}}
-;;{{{ google mobile
-(emacspeak-websearch-set-searcher 'google-mobile
-                                  'emacspeak-websearch-google-mobile)
-
-(emacspeak-websearch-set-key ?\; 'google-mobile)
-
-(defvar emacspeak-websearch-google-mobile-uri
-  "https://www.google.com/xhtml?q="
-  "Google mobile search.")
-
-;;;###autoload
-(defun emacspeak-websearch-google-mobile (query)
-  "Google mobile search."
-  (interactive
-   (list
-    (gweb-google-autocomplete "Google Mobile: ")))
-  (declare (special emacspeak-websearch-google-mobile-uri))
-  (browse-url
-   (concat emacspeak-websearch-google-mobile-uri
-           (emacspeak-url-encode query)))
-  (emacspeak-webutils-post-process
-   query
-   'emacspeak-speak-rest-of-buffer))
-
 ;;}}}
 ;;{{{ Google News
 
@@ -1030,26 +735,6 @@ https://www.google.com/options/specialsearches.html "
     (emacspeak-url-template-open
      (emacspeak-url-template-get name))))
 
-;;}}}
-;;{{{  advanced usenet search
-
-(emacspeak-websearch-set-searcher 'google-usenet-advanced
-                                  'emacspeak-websearch-google-usenet-advanced)
-
-(emacspeak-websearch-set-key ?u 'google-usenet-advanced)
-
-(defvar emacspeak-websearch-google-usenet-advanced-form
-  (expand-file-name "xml-forms/google-usenet-advanced.xml"
-                    emacspeak-lisp-directory)
-  "Usenet advanced search from google.")
-
-;;;###autoload
-(defun emacspeak-websearch-google-usenet-advanced ()
-  "Present Google Usenet advanced search form simplified for speech interaction."
-  (interactive)
-  (declare (special emacspeak-websearch-google-usenet-advanced-form))
-  (emacspeak-websearch-display-form emacspeak-websearch-google-usenet-advanced-form))
-
 ;;}}}
 ;;{{{  Ask Jeeves
 
@@ -1072,78 +757,6 @@ https://www.google.com/options/specialsearches.html "
            (emacspeak-url-encode query)))
   (emacspeak-webutils-post-process query 'emacspeak-speak-line))
 
-;;}}}
-;;{{{ Driving directions from Yahoo
-
-(emacspeak-websearch-set-searcher 'map-yahoo-directions
-                                  'emacspeak-websearch-map-yahoo-directions-search)
-(emacspeak-websearch-set-key ?m 'map-yahoo-directions)
-
-(defvar emacspeak-websearch-map-yahoo-directions-uri
-  "http://maps.yahoo.com/py/ddResults.py?Pyt=Tmap&doit=1&newname=&newdesc=&Get+Directions=Get+Directions&textonly=1"
-  "URI for getting driving directions from Yahoo.")
-
-(defvar emacspeak-websearch-map-yahoomaps-uri
-  "http://maps.yahoo.com/py/maps.py?Pyt=Tmap&Get%A0Map=Get+Map&"
-  "URI for obtaining location maps.")
-
-(defsubst emacspeak-websearch-map-yahoomaps-get-location ()
-  "Convenience function for prompting and constructing the route component."
-  (concat
-   (format "&addr=%s"
-           (emacspeak-url-encode
-            (read-from-minibuffer "Street Address: ")))
-   (format "&csz=%s"
-           (emacspeak-url-encode
-            (read-from-minibuffer "City/State or Zip:")))))
-
-(defsubst emacspeak-websearch-map-yahoo-directions-get-locations ()
-  "Convenience function for prompting and constructing the route component."
-  (concat
-   (format "&newaddr=%s"
-           (emacspeak-url-encode
-            (read-from-minibuffer "Start Address: ")))
-   (format "&newcsz=%s"
-           (emacspeak-url-encode
-            (read-from-minibuffer "City/State or Zip:")))
-   (format "&newtaddr=%s"
-           (emacspeak-url-encode
-            (read-from-minibuffer "Destination Address: ")))
-   (format "&newtcsz=%s"
-           (emacspeak-url-encode
-            (read-from-minibuffer "City/State or Zip:")))))
-
-;;;###autoload
-(defun emacspeak-websearch-map-yahoo-directions-search (query
-                                                        &optional map)
-  "Get driving directions from Yahoo.
-With optional interactive prefix arg MAP shows the location map instead."
-  (interactive
-   (list
-    (if current-prefix-arg
-        (emacspeak-websearch-map-yahoomaps-get-location)
-      (emacspeak-websearch-map-yahoo-directions-get-locations))
-    current-prefix-arg))
-  (declare (special emacspeak-websearch-map-yahoo-directions-uri
-                    emacspeak-xslt-use-wget-to-download
-                    emacspeak-websearch-map-yahoomaps-uri))
-  (let ((emacspeak-xslt-use-wget-to-download t))
-    (cond
-     (map
-      (browse-url
-       (concat
-        emacspeak-websearch-map-yahoomaps-uri
-        query))
-      (emacspeak-webutils-post-process
-       "Nearby"
-       'emacspeak-speak-line))
-     (t
-      (emacspeak-we-extract-table-by-match "Start"
-                                           (concat
-                                            emacspeak-websearch-map-yahoo-directions-uri
-                                            query)
-                                           'speak)))))
-
 ;;}}}
 ;;{{{  news yahoo
 
@@ -1215,52 +828,6 @@ Optional prefix arg no-rss scrapes information from HTML."
    "Search results"
    'emacspeak-speak-line))
 
-;;}}}
-;;{{{ RPMFind
-
-(emacspeak-websearch-set-searcher 'rpm-find
-                                  'emacspeak-websearch-rpm-find)
-
-(emacspeak-websearch-set-key 18 'rpm-find)
-
-(defvar emacspeak-websearch-rpm-find-uri
-  "http://rpmfind.net/linux/rpm2html/search.php?query="
-  "*URI for RPM  Site search")
-
-;;;###autoload
-(defun emacspeak-websearch-rpm-find (query)
-  "Search RPM  catalog  site."
-  (interactive
-   (list
-    (emacspeak-websearch-read-query "Find RPM: ")))
-  (declare (special emacspeak-websearch-rpm-find-uri))
-  (browse-url
-   (concat emacspeak-websearch-rpm-find-uri
-           (emacspeak-url-encode query)))
-  (emacspeak-webutils-post-process
-   query
-   'emacspeak-speak-line))
-
-;;}}}
-;;{{{  Recorded books
-
-(emacspeak-websearch-set-searcher 'recorded-books
-                                  'emacspeak-websearch-recorded-books-search)
-
-                                        ;(emacspeak-websearch-set-key ?r 'recorded-books)
-
-(defvar emacspeak-websearch-recorded-books-advanced-form
-  (expand-file-name "xml-forms/recorded-books-advanced.xml"
-                    emacspeak-lisp-directory)
-  "Search form for finding recorded books.")
-
-;;;###autoload
-(defun emacspeak-websearch-recorded-books-search ()
-  "Present advanced search form for recorded books."
-  (interactive)
-  (declare (special emacspeak-websearch-recorded-books-advanced-form))
-  (emacspeak-websearch-display-form emacspeak-websearch-recorded-books-advanced-form))
-
 ;;}}}
 ;;{{{ Merriam Webster
 
@@ -1309,31 +876,6 @@ Optional prefix arg no-rss scrapes information from HTML."
            (emacspeak-url-encode query))
    'speak))
 
-;;}}}
-;;{{{ W3C
-
-(emacspeak-websearch-set-searcher 'w3c
-                                  'emacspeak-websearch-w3c-search)
-(emacspeak-websearch-set-key ?W 'w3c)
-
-(defvar emacspeak-websearch-w3c-search-uri
-  "http://search.w3.org/Member/cgi-bin/query?mss=simple&pg=q&what=web&filter=all&fmt=."
-  "URI for searching the member area of the W3C site.")
-
-;;;###autoload
-(defun emacspeak-websearch-w3c-search (query)
-  "Search the W3C Site."
-  (interactive
-   (list (emacspeak-websearch-read-query "Search W3C site: ")))
-  (declare (special emacspeak-websearch-w3c-search-uri))
-  (browse-url
-   (concat emacspeak-websearch-w3c-search-uri
-           "&q="
-           (emacspeak-url-encode query)))
-  (emacspeak-webutils-post-process
-   "match"
-   'emacspeak-speak-line))
-
 ;;}}}
 ;;{{{ wikipedia
 
@@ -1347,8 +889,7 @@ Optional prefix arg no-rss scrapes information from HTML."
   "Search Wikipedia using Google."
   (interactive
    (list (emacspeak-websearch-read-query "Search Wikipedia: ")))
-  
-  
+
   (emacspeak-websearch-google
    (emacspeak-url-encode (format "site:wikipedia.org %s"query))))
 
@@ -1378,34 +919,34 @@ Results"
    'emacspeak-speak-line))
 
 ;;}}}
-;;{{{ Exchange rate convertor
+;;{{{ Exchange rate converter
 
-(emacspeak-websearch-set-searcher 'exchange-rate-convertor
-                                  'emacspeak-websearch-exchange-rate-convertor)
+(emacspeak-websearch-set-searcher 'exchange-rate-converter
+                                  'emacspeak-websearch-exchange-rate-converter)
 
-(emacspeak-websearch-set-key ?X 'exchange-rate-convertor)
+(emacspeak-websearch-set-key ?X 'exchange-rate-converter)
 
 (defvar emacspeak-websearch-exchange-rate-form
-  (expand-file-name "xml-forms/exchange-rate-convertor.xml"
+  (expand-file-name "xml-forms/exchange-rate-converter.xml"
                     emacspeak-lisp-directory)
   "Form for performing currency conversion.")
 
-(defvar emacspeak-websearch-exchange-rate-convertor-uri
+(defvar emacspeak-websearch-exchange-rate-converter-uri
   "http://www.xe.com/ucc/convert.cgi?Amount=1&From=%s&To=%s&submit=Perform+Conversion"
   "URI template  for currency conversion.")
 
 ;;;###autoload
-(defun emacspeak-websearch-exchange-rate-convertor (conversion-spec)
-  "Currency convertor."
+(defun emacspeak-websearch-exchange-rate-converter (conversion-spec)
+  "Currency converter."
   (interactive
    (list
     (read-from-minibuffer
      "Currency Convertor: FROM|TO:")))
-  (declare (special emacspeak-websearch-exchange-rate-convertor-uri))
+  (declare (special emacspeak-websearch-exchange-rate-converter-uri))
   (let ((fields (split-string conversion-spec "|"))
         (url nil))
     (setq url
-          (format emacspeak-websearch-exchange-rate-convertor-uri
+          (format emacspeak-websearch-exchange-rate-converter-uri
                   (upcase (first fields))
                   (upcase (second fields))))
     (emacspeak-we-extract-table-by-match
@@ -1413,27 +954,27 @@ Results"
      url 'speak)))
 
 ;;}}}
-;;{{{ Yahoo Exchange rate convertor
+;;{{{ Yahoo Exchange rate converter
 
-(emacspeak-websearch-set-searcher 'y-exchange-rate-convertor
-                                  'emacspeak-websearch-yahoo-exchange-rate-convertor)
+(emacspeak-websearch-set-searcher 'y-exchange-rate-converter
+                                  'emacspeak-websearch-yahoo-exchange-rate-converter)
 
-(emacspeak-websearch-set-key ?x 'y-exchange-rate-convertor)
+(emacspeak-websearch-set-key ?x 'y-exchange-rate-converter)
 
-(defvar emacspeak-websearch-yahoo-exchange-rate-convertor-uri
+(defvar emacspeak-websearch-yahoo-exchange-rate-converter-uri
   "http://download.finance.yahoo.com/d/quotes.csv?s=%s=X&f=sl1d1t1ba&e=.csv"
   "URI template  for currency conversion.")
 
 ;;;###autoload
-(defun emacspeak-websearch-yahoo-exchange-rate-convertor (conversion-spec)
-  "Currency convertor."
+(defun emacspeak-websearch-yahoo-exchange-rate-converter (conversion-spec)
+  "Currency converter."
   (interactive
    (list
     (read-from-minibuffer
      "Currency Convertor: FromTo:")))
-  (declare (special emacspeak-websearch-yahoo-exchange-rate-convertor-uri))
-  (let* ((url 
-          (format emacspeak-websearch-yahoo-exchange-rate-convertor-uri
+  (declare (special emacspeak-websearch-yahoo-exchange-rate-converter-uri))
+  (let* ((url
+          (format emacspeak-websearch-yahoo-exchange-rate-converter-uri
                   (upcase  conversion-spec)))
          (buffer (url-retrieve-synchronously url)))
     (save-excursion
@@ -1466,26 +1007,6 @@ Results"
   (declare (special emacspeak-websearch-amazon-search-form))
   (browse-url emacspeak-websearch-amazon-search-form))
 
-;;}}}
-;;{{{ Shopping at ebay
-
-(emacspeak-websearch-set-searcher 'ebay-search
-                                  'emacspeak-websearch-ebay-search)
-
-(emacspeak-websearch-set-key 5 'ebay-search)
-
-(defvar emacspeak-websearch-ebay-search-form
-  (expand-file-name "xml-forms/ebay-search.xml"
-                    emacspeak-lisp-directory)
-  "Form for Ebay store search.")
-
-;;;###autoload
-(defun emacspeak-websearch-ebay-search ()
-  "Ebay search."
-  (interactive)
-  (declare (special emacspeak-websearch-ebay-search-form))
-  (emacspeak-websearch-display-form emacspeak-websearch-ebay-search-form))
-
 ;;}}}
 ;;{{{  site-specific search tools
 
@@ -1495,49 +1016,6 @@ Results"
   (load-library "emacspeak-w3search"))
 
 ;;}}}
-;;{{{ Browse usenet
-
-(defvar emacspeak-usenet-feeds-uri
-  "http://groups.google.com/group/%s/feed/rss_v2_0_msgs.xml"
-  "RSS Feed from Google for Usenet groups.")
-
-(defvar emacspeak-usenet-uri
-  "http://groups.google.com/group/"
-  "URI to open a group on Usenet archive.")
-;;;###autoload
-(defun emacspeak-websearch-usenet (group &optional prefix)
-  "Prompt and browse a Usenet newsgroup.
-Optional interactive prefix arg results in prompting for a search term."
-  (interactive
-   (list
-    (read-from-minibuffer "Newsgroup: ")
-    current-prefix-arg))
-  (declare (special emacspeak-usenet-uri
-                    emacspeak-usenet-feeds-uri))
-  (let ((url nil))
-    (cond
-     (prefix                            ;search
-      (setq url
-            (format
-             "%s%s/search?group=%s&q=%s&qt_g=1&searchnow=Search+this+group&num=%s&scoring=d"
-             emacspeak-usenet-uri
-             group group
-             (emacspeak-url-encode
-              (read-from-minibuffer
-               (format "Search %s for:" group)))
-             emacspeak-websearch-google-number-of-results))
-      (emacspeak-webutils-without-xsl
-       (browse-url  url)
-       (emacspeak-webutils-post-process
-        "Sort by"
-        'emacspeak-speak-line)))
-     (t                                 ;browse
-      (setq url
-            (format emacspeak-usenet-feeds-uri group))
-      (emacspeak-feeds-rss-display url)))))
-
-;;}}}
-
 ;;}}}
 (provide 'emacspeak-websearch)
 ;;{{{ end of file
