@@ -1,5 +1,5 @@
 ;;; emacspeak.el --- Emacspeak -- The Complete Audio Desktop
-;;; $Id: emacspeak.el 9454 2014-09-19 16:03:28Z tv.raman.tv $
+;;; $Id$
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Emacspeak: A speech interface to Emacs
 ;;; Keywords: Emacspeak, Speech, Dectalk,
@@ -15,7 +15,7 @@
 
 ;;}}}
 ;;{{{  Copyright:
-;;;Copyright (C) 1995 -- 2011, T. V. Raman
+;;;Copyright (C) 1995 -- 2015, T. V. Raman
 ;;; Copyright (c) 1994, 1995 by Digital Equipment Corporation.
 ;;; All Rights Reserved.
 ;;;
@@ -39,12 +39,13 @@
 ;;{{{ Introduction
 
 ;;; Commentary:
-;;;The complete audio desktop.
 
 ;;;Emacspeak extends Emacs to be a fully functional audio desktop.
 ;;; This is the main emacspeak module.
 ;;; It actually does very little:
-;;; It loads the various parts of the system.
+;;; It sets up Emacs to load package-specific Emacspeak modules as each package is loaded.
+;;; It implements function emacspeak which loads the rest of the system.
+
 ;;; Code:
 
 ;;}}}
@@ -53,16 +54,17 @@
 (require 'cl)
 (declaim  (optimize  (safety 0) (speed 3)))
 (require 'emacspeak-preamble)
-(require 'dtk-speak)
 (require 'emacspeak-sounds)
+(require 'emacspeak-fix-interactive)
 
 ;;}}}
 ;;{{{ autoloads
 
-(load-library "emacspeak-loaddefs")
-(load-library "emacspeak-cus-load")
-(load-library "g-loaddefs")
-(load-library "g-client/g-cus-load")
+(unless noninteractive
+  (load-library "emacspeak-loaddefs")
+  (load-library "emacspeak-cus-load")
+  (load-library "g-loaddefs")
+  (load-library "g-cus-load"))
 
 ;;}}}
 ;;{{{  Customize groups
@@ -104,6 +106,7 @@ the Emacspeak desktop." )
   :prefix "emacspeak-"
   :group 'applications
   :group 'accessibility)
+
 ;;;###autoload
 (defcustom emacspeak-startup-hook nil
   "Hook to run after starting emacspeak."
@@ -111,21 +114,18 @@ the Emacspeak desktop." )
   :group 'emacspeak)
 
 ;;;###autoload
-(defcustom emacspeak-media-player 'emacspeak-m-player
+(defvar emacspeak-media-player 'emacspeak-m-player
   "Default media player to use.
-This is a Lisp function that takes a resource locator."
-  :type 'function
-  :group 'emacspeak)
+This is a Lisp function that takes a resource locator.")
 
 ;;}}}
 ;;{{{ Package Setup Helper
 
 (defun emacspeak-do-package-setup (package module)
-  "Setup Emacspeak extension for a specific PACKAGE.
-This function adds the appropriate form to `after-load-alist' to
-set up Emacspeak support for a given package. Argument MODULE
-specifies the emacspeak module that implements the
-speech-enabling extensions."
+  "Setup Emacspeak extension for a specific PACKAGE. This function adds
+the appropriate form to `after-load-alist' to set up Emacspeak support
+for a given package. Argument MODULE specifies the emacspeak module
+that implements the speech-enabling extensions."
   (eval-after-load package
     `(progn
        (require ',module)
@@ -136,6 +136,10 @@ speech-enabling extensions."
         (locate-library
          ,(format "%s" package))))))
 
+;;; DocView
+(eval-after-load 'doc-view
+  `(add-hook 'doc-view-mode-hook 'doc-view-open-text))
+
 ;;}}}
 ;;{{{ Setup package extensions
 
@@ -145,7 +149,6 @@ speech-enabling extensions."
 (emacspeak-do-package-setup "apt-sources" 'emacspeak-apt-sources)
 (emacspeak-do-package-setup "apt-utils" 'emacspeak-apt-utils)
 (emacspeak-do-package-setup "arc-mode" 'emacspeak-arc)
-(emacspeak-do-package-setup "babel" 'emacspeak-babel )
 (emacspeak-do-package-setup "bbdb" 'emacspeak-bbdb )
 (emacspeak-do-package-setup "bibtex" 'emacspeak-bibtex)
 (emacspeak-do-package-setup "bookmark" 'emacspeak-bookmark)
@@ -166,15 +169,14 @@ speech-enabling extensions."
 (emacspeak-do-package-setup "cperl-mode" 'emacspeak-cperl)
 (emacspeak-do-package-setup "pianobar" 'emacspeak-pianobar)
 (emacspeak-do-package-setup "proced" 'emacspeak-proced)
+(emacspeak-do-package-setup "projectile" 'emacspeak-projectile)
 (emacspeak-do-package-setup "ecb" 'emacspeak-ecb)
 (emacspeak-do-package-setup "ein" 'emacspeak-ein)
 (emacspeak-do-package-setup "cus-edit" 'emacspeak-custom)
-(emacspeak-do-package-setup "damlite" 'emacspeak-damlite)
 (emacspeak-do-package-setup "desktop" 'emacspeak-desktop )
 (emacspeak-do-package-setup "diff-mode" 'emacspeak-diff-mode )
 (emacspeak-do-package-setup "dired" 'emacspeak-dired )
 (emacspeak-do-package-setup "dismal" 'emacspeak-dismal)
-(emacspeak-do-package-setup "dictation" 'emacspeak-dictation)
 (emacspeak-do-package-setup "dictionary" 'emacspeak-dictionary)
 (emacspeak-do-package-setup "dmacro" 'emacspeak-dmacro)
 (emacspeak-do-package-setup "doctor" 'emacspeak-entertain)
@@ -190,6 +192,7 @@ speech-enabling extensions."
 (emacspeak-do-package-setup "ess" 'emacspeak-ess)
 (emacspeak-do-package-setup "eclim" 'emacspeak-eclim)
 (emacspeak-do-package-setup "eww" 'emacspeak-eww)
+(emacspeak-do-package-setup "elfeed" 'emacspeak-elfeed)
 (emacspeak-do-package-setup "enriched" 'emacspeak-enriched)
 (emacspeak-do-package-setup "facemenu" 'emacspeak-facemenu)
 (emacspeak-do-package-setup "find-dired" 'emacspeak-find-dired)
@@ -206,15 +209,16 @@ speech-enabling extensions."
 (emacspeak-do-package-setup "gomoku" 'emacspeak-gomoku)
 (emacspeak-do-package-setup "gud" 'emacspeak-gud)
 (emacspeak-do-package-setup "gdb-ui" 'emacspeak-gud)
+(emacspeak-do-package-setup "helm" 'emacspeak-helm)
 (emacspeak-do-package-setup "go-mode" 'emacspeak-go-mode)
 (emacspeak-do-package-setup "hangman" 'emacspeak-entertain)
 (emacspeak-do-package-setup "hideshow" 'emacspeak-hideshow)
+(emacspeak-do-package-setup "hydra" 'emacspeak-muggles)
 (emacspeak-do-package-setup "imenu" 'emacspeak-imenu)
 (emacspeak-do-package-setup "ibuffer" 'emacspeak-ibuffer)
 (emacspeak-do-package-setup "ido" 'emacspeak-ido)
 (emacspeak-do-package-setup "info" 'emacspeak-info)
 (emacspeak-do-package-setup "ispell" 'emacspeak-ispell)
-(emacspeak-do-package-setup "iswi" 'emacspeak-iswitchb)
 (emacspeak-do-package-setup "jabber" 'emacspeak-jabber)
 (emacspeak-do-package-setup "jde" 'emacspeak-jde)
 (emacspeak-do-package-setup "js2" 'emacspeak-js2)
@@ -222,8 +226,10 @@ speech-enabling extensions."
 (emacspeak-do-package-setup "jss" 'emacspeak-jss)
 (emacspeak-do-package-setup "kite" 'emacspeak-kite)
 (emacspeak-do-package-setup "kmacro" 'emacspeak-kmacro)
+(emacspeak-do-package-setup"lua-mdoe" 'emacspeak-lua)
 (emacspeak-do-package-setup "magit" 'emacspeak-magit)
 (emacspeak-do-package-setup "make-mode" 'emacspeak-make-mode)
+(emacspeak-do-package-setup "markdown-mode" 'emacspeak-markdown)
 (emacspeak-do-package-setup "man" 'emacspeak-man)
 (emacspeak-do-package-setup "message" 'emacspeak-message)
 (emacspeak-do-package-setup "meta-mode" 'emacspeak-metapost)
@@ -240,9 +246,9 @@ speech-enabling extensions."
 (emacspeak-do-package-setup "outline" 'emacspeak-outline)
 (emacspeak-do-package-setup "perl-mode" 'emacspeak-perl)
 (emacspeak-do-package-setup "php-mode" 'emacspeak-php-mode)
-(emacspeak-do-package-setup "pcl-cvs" 'emacspeak-pcl-cvs)
+(emacspeak-do-package-setup "package"'emacspeak-package)
+(emacspeak-do-package-setup "paradox"'emacspeak-paradox)
 (emacspeak-do-package-setup "pcvs" 'emacspeak-pcl-cvs)
-(emacspeak-do-package-setup "psgml" 'emacspeak-psgml)
 (emacspeak-do-package-setup "python" 'emacspeak-python)
 (emacspeak-do-package-setup "python-mode" 'emacspeak-py)
 (emacspeak-do-package-setup "re-builder" 'emacspeak-re-builder)
@@ -252,6 +258,7 @@ speech-enabling extensions."
 (emacspeak-do-package-setup "ruby-mode" 'emacspeak-ruby)
 (emacspeak-do-package-setup "sgml-mode" 'emacspeak-sgml-mode)
 (emacspeak-do-package-setup "sh-script" 'emacspeak-sh-script)
+(emacspeak-do-package-setup "slime" 'emacspeak-slime)
 (emacspeak-do-package-setup "sigbegone" 'emacspeak-sigbegone)
 (emacspeak-do-package-setup "solitaire" 'emacspeak-solitaire)
 (emacspeak-do-package-setup "speedbar" 'emacspeak-speedbar)
@@ -260,15 +267,12 @@ speech-enabling extensions."
 (emacspeak-do-package-setup "sql" 'emacspeak-sql)
 (emacspeak-do-package-setup "supercite" 'emacspeak-supercite)
 (emacspeak-do-package-setup "sudoku" 'emacspeak-sudoku)
-(emacspeak-do-package-setup "swbuff" 'emacspeak-swbuff)
 (emacspeak-do-package-setup "table" 'emacspeak-etable)
 (emacspeak-do-package-setup "tar-mode" 'emacspeak-tar)
 (emacspeak-do-package-setup "tcl" 'emacspeak-tcl)
 (emacspeak-do-package-setup "tdtd" 'emacspeak-tdtd)
-(emacspeak-do-package-setup "xslide" 'emacspeak-xslide)
-(emacspeak-do-package-setup "xslt-process" 'emacspeak-xslt-process)
+(emacspeak-do-package-setup "xref" 'emacspeak-xref)
 (emacspeak-do-package-setup "tempo" 'emacspeak-tempo)
-(emacspeak-do-package-setup "tnt" 'emacspeak-tnt)
 (emacspeak-do-package-setup "term" 'emacspeak-eterm )
 (emacspeak-do-package-setup "eudc" 'emacspeak-eudc )
 (emacspeak-do-package-setup "tetris" 'emacspeak-tetris)
@@ -292,13 +296,13 @@ speech-enabling extensions."
 (emacspeak-do-package-setup "windmove" 'emacspeak-windmove)
 (emacspeak-do-package-setup "winring" 'emacspeak-winring)
 (emacspeak-do-package-setup "woman" 'emacspeak-woman)
-
+(emacspeak-do-package-setup "yasnippet" 'emacspeak-yasnippet)
 ;;}}}
 ;;{{{  Submit bugs
 
 (defconst emacspeak-bug-address
-  "raman@cs.cornell.edu"
-  "Address of the maintainer of this package.")
+  "emacspeak@cs.vassar.edu"
+  "Address for bug reports and questions.")
 
 (defun emacspeak-submit-bug ()
   "Function to submit a bug to the programs maintainer."
@@ -336,8 +340,7 @@ speech-enabling extensions."
   "Export shell environment.
 This exports emacspeak's system variables to the environment
 so it can be passed to subprocesses."
-  (declare (special emacspeak-directory
-                    emacspeak-play-program
+  (declare (special emacspeak-directory emacspeak-play-program
                     emacspeak-sounds-directory))
   (setenv "EMACSPEAK_DIR" emacspeak-directory)
   (setenv "EMACSPEAK_SOUNDS_DIR" emacspeak-sounds-directory)
@@ -359,7 +362,8 @@ sets punctuation mode to all, activates the dictionary and turns on split caps."
   (emacspeak-pronounce-refresh-pronunciations)
   (or emacspeak-audio-indentation
       (emacspeak-toggle-audio-indentation))
-  (emacspeak-dtk-sync))
+  (emacspeak-dtk-sync)
+  (hs-minor-mode 1))
 
 (defun emacspeak-setup-programming-modes ()
   "Setup programming modes."
@@ -370,12 +374,13 @@ sets punctuation mode to all, activates the dictionary and turns on split caps."
    (list
     'prog-mode-hook'c-mode-common-hook
     'conf-unix-mode-hook
-    'prolog-mode-hook
+    'prolog-mode-hook 'markdown-mode-hook
     'lisp-mode-hook
     'emacs-lisp-mode-hook
     'lisp-interaction-mode-hook
     'javascript-mode-hook
     'js2-mode-hook
+    'lua-mode-hook
     'scala-mode-hook
     'midge-mode-hook
     'meta-common-mode-hook
@@ -423,7 +428,7 @@ sets punctuation mode to all, activates the dictionary and turns on split caps."
                      (expand-file-name "emacspeak.mp3" emacspeak-sounds-directory)))))
 ;;;###autoload
 (defun emacspeak()
-  "Starts the Emacspeak speech subsystem.  Use emacs as you
+  "Starts the Emacspeak  Audio Desktop.  Use emacs as you
 normally would, emacspeak will provide you spoken feedback
 as you work.  Emacspeak also provides commands for having
 parts of the current buffer, the mode-line etc to be spoken.
@@ -453,8 +458,7 @@ functions for details.   "
   (interactive)
   (declare (special emacspeak-pronounce-load-pronunciations-on-startup
                     emacspeak-pronounce-dictionaries-file
-                    emacspeak-play-program
-                    emacspeak-sounds-directory))
+                    emacspeak-play-program emacspeak-sounds-directory))
   (emacspeak-export-environment)
   (require 'emacspeak-personality)
   (dtk-initialize)
