@@ -3,22 +3,15 @@
 ;;; Code:
 
 (put 'applications 'custom-loads '(g))
-(put 'g 'custom-loads '(g-auth g-utils gblogger gbooks gcal gcontacts gdocs gfeeds gmaps gnotebook gphoto gsheet gskeleton gtube gweb))
+(put 'g 'custom-loads '(g-auth g-utils gblogger gdocs gfeeds gmaps gphoto gskeleton gweb))
 (put 'g-auth 'custom-loads '(g-auth))
 (put 'gblogger 'custom-loads '(gblogger))
-(put 'gbooks 'custom-loads '(gbooks))
-(put 'gcal 'custom-loads '(gcal))
-(put 'gcontacts 'custom-loads '(gcontacts))
 (put 'gdocs 'custom-loads '(gdocs))
 (put 'gfeeds 'custom-loads '(gfeeds))
 (put 'gmaps 'custom-loads '(gmaps))
-(put 'gnotebook 'custom-loads '(gnotebook))
 (put 'gphoto 'custom-loads '(gphoto))
-(put 'gsheet 'custom-loads '(gsheet))
 (put 'gskeleton 'custom-loads '(gskeleton))
-(put 'gtube 'custom-loads '(gtube))
 (put 'gweb 'custom-loads '(gmaps))
-(put 'gwis 'custom-loads '(gwis))
 
 ;; The remainder of this file is for handling :version.
 ;; We provide a minimum of information so that `customize-changed-options'
