@@ -1,6 +1,6 @@
 ;;;Auto generated
 
-;;;### (autoloads nil "g-auth" "g-auth.el" (20985 36762 0 0))
+;;;### (autoloads nil "g-auth" "g-auth.el" (21899 16918 252133 30000))
 ;;; Generated autoloads from g-auth.el
 
 (defvar g-auth-lifetime "4 hours" "\
@@ -10,7 +10,8 @@ Auth lifetime.")
 
 ;;;***
 
-;;;### (autoloads nil "gblogger" "gblogger.el" (20762 27152 0 0))
+;;;### (autoloads nil "gblogger" "gblogger.el" (21924 18924 869030
+;;;;;;  24000))
 ;;; Generated autoloads from gblogger.el
 
 (autoload 'gblogger-blog "gblogger" "\
@@ -24,7 +25,7 @@ Retrieve and display specified feed after authenticating.
 \(fn FEED-URL)" t nil)
 
 (autoload 'gblogger-edit-entry "gblogger" "\
-Retrieve entry and prepare it for editting.
+Retrieve entry and prepare it for editing.
 The retrieved entry is placed in a buffer ready for editing.
 `url' is the URL of the entry.
 
@@ -41,7 +42,7 @@ Delete item at specified edit URL.
 \(fn EDIT-URL)" t nil)
 
 (autoload 'gblogger-add-label "gblogger" "\
-Adds labels to gblogger entry being editted.
+Adds labels to gblogger entry being edited.
 
 \(fn LABEL)" t nil)
 
@@ -57,105 +58,7 @@ Resets client so you can start with a different userid.
 
 ;;;***
 
-;;;### (autoloads nil "gbooks" "gbooks.el" (20762 27152 0 0))
-;;; Generated autoloads from gbooks.el
-
-(autoload 'gbooks-sign-out "gbooks" "\
-Resets client so you can start with a different userid.
-
-\(fn)" t nil)
-
-(autoload 'gbooks-sign-in "gbooks" "\
-Resets client so you can start with a different userid.
-
-\(fn)" t nil)
-
-;;;***
-
-;;;### (autoloads nil "gcal" "gcal.el" (20762 27152 0 0))
-;;; Generated autoloads from gcal.el
-
-(defvar gcal-default-user-email nil "\
-Default user id for Calendar.")
-
-(custom-autoload 'gcal-default-user-email "gcal" t)
-
-(defvar gcal-user-email nil "\
-Mail address that identifies calendar user.")
-
-(custom-autoload 'gcal-user-email "gcal" t)
-
-(autoload 'gcal-add-event "gcal" "\
-Add a calendar event.
-
-\(fn)" t nil)
-
-(autoload 'gcal-quickadd-event "gcal" "\
-Add a calendar event.
-Specify the event in plain English.
-
-\(fn EVENT-DESC)" t nil)
-
-(autoload 'gcal-delete-event "gcal" "\
-Delete a calendar event.
-
-\(fn EVENT-URI)" t nil)
-
-(autoload 'gcal-reject-event "gcal" "\
-Reject (RSVP)  a calendar event.
-
-\(fn EVENT-URI)" t nil)
-
-(defvar gcal-calendar-agenda-days 5 "\
-Number of days for which we show an agenda by default.")
-
-(custom-autoload 'gcal-calendar-agenda-days "gcal" t)
-
-(autoload 'gcal-view "gcal" "\
-Retrieve and display resource after authenticating.
-
-\(fn RESOURCE)" t nil)
-
-(autoload 'gcal-show-event "gcal" "\
-Show event at URL.
-
-\(fn URL)" t nil)
-
-(define-prefix-command 'gcal-calendar-prefix-map)
-
-(autoload 'gcal-emacs-calendar-setup "gcal" "\
-Setup GCal keybindings in Emacs calendar.
-
-\(fn)" nil nil)
-
-(autoload 'gcal-sign-out "gcal" "\
-Resets client so you can start with a different userid.
-
-\(fn)" t nil)
-
-(autoload 'gcal-sign-in "gcal" "\
-Sign in, useful when changing to a different user profile.
-
-\(fn)" t nil)
-
-;;;***
-
-;;;### (autoloads nil "gcontacts" "gcontacts.el" (20762 27152 0 0))
-;;; Generated autoloads from gcontacts.el
-
-(autoload 'gcontacts-initialize "gcontacts" "\
-Initialize GContacts process handle.
-
-\(fn USERNAME)" t nil)
-
-(autoload 'gcontacts-create "gcontacts" "\
-Create a new contact as specified.
-
-\(fn NAME EMAIL MOBILE)" t nil)
-
-;;;***
-
-;;;### (autoloads nil "gdocs" "gdocs.el" (20762 27152 0 0))
+;;;### (autoloads nil "gdocs" "gdocs.el" (21857 972 0 0))
 ;;; Generated autoloads from gdocs.el
 
 (autoload 'gdocs-doclist "gdocs" "\
@@ -197,7 +100,7 @@ Resets client so you can start with a different userid.
 
 ;;;***
 
-;;;### (autoloads nil "gfeeds" "gfeeds.el" (21560 21296 481418 94000))
+;;;### (autoloads nil "gfeeds" "gfeeds.el" (21857 972 0 0))
 ;;; Generated autoloads from gfeeds.el
 
 (defsubst gfeeds-feed (feed-url) "\
@@ -227,7 +130,7 @@ Interactive prefix arg causes the feed url to be looked up given a Web site.
 
 ;;;***
 
-;;;### (autoloads nil "gm-nnir" "gm-nnir.el" (21244 5293 0 0))
+;;;### (autoloads nil "gm-nnir" "gm-nnir.el" (21857 972 0 0))
 ;;; Generated autoloads from gm-nnir.el
 
 (autoload 'gm-nnir-group-make-nnir-group "gm-nnir" "\
@@ -245,7 +148,7 @@ Default is to search All Mail when not on a Group line.
 
 ;;;***
 
-;;;### (autoloads nil "gmaps" "gmaps.el" (21343 55314 0 0))
+;;;### (autoloads nil "gmaps" "gmaps.el" (21857 972 0 0))
 ;;; Generated autoloads from gmaps.el
 
 (autoload 'gmaps-geocode "gmaps" "\
@@ -275,7 +178,7 @@ Google Maps Interaction.
 
 ;;;***
 
-;;;### (autoloads nil "gphoto" "gphoto.el" (20762 27152 0 0))
+;;;### (autoloads nil "gphoto" "gphoto.el" (21857 972 0 0))
 ;;; Generated autoloads from gphoto.el
 
 (autoload 'gphoto-feeds "gphoto" "\
@@ -363,32 +266,7 @@ The retrieved entry is placed in a buffer ready for editing.
 
 ;;;***
 
-;;;### (autoloads nil "gsheet" "gsheet.el" (20762 27152 0 0))
-;;; Generated autoloads from gsheet.el
-
-(autoload 'gsheet-fetch "gsheet" "\
-Fetch specified sheet.
-
-\(fn SHEET-URL)" t nil)
-
-(autoload 'gsheet-sheets "gsheet" "\
-Retrieve and display feed of feeds after authenticating.
-
-\(fn)" t nil)
-
-(autoload 'gsheet-sign-out "gsheet" "\
-Resets client so you can start with a different userid.
-
-\(fn)" t nil)
-
-(autoload 'gsheet-sign-in "gsheet" "\
-Resets client so you can start with a different userid.
-
-\(fn)" t nil)
-
-;;;***
-
-;;;### (autoloads nil "gskeleton" "gskeleton.el" (20762 27152 0 0))
+;;;### (autoloads nil "gskeleton" "gskeleton.el" (21857 972 0 0))
 ;;; Generated autoloads from gskeleton.el
 
 (autoload 'gskeleton-sign-out "gskeleton" "\
@@ -403,76 +281,12 @@ Resets client so you can start with a different userid.
 
 ;;;***
 
-;;;### (autoloads nil "gtube" "gtube.el" (20762 27152 0 0))
-;;; Generated autoloads from gtube.el
-
-(autoload 'gtube-user-profile "gtube" "\
-Retrieve user profile.
-
-\(fn &optional USER)" t nil)
-
-(autoload 'gtube-user-favorites "gtube" "\
-Retrieve user favorites.
-
-\(fn &optional USER)" t nil)
-
-(autoload 'gtube-user-friends "gtube" "\
-Retrieve user profile.
-
-\(fn &optional USER)" t nil)
-
-(autoload 'gtube-video-details "gtube" "\
-Display details of specified video.
-
-\(fn VIDEO-ID)" t nil)
-
-(autoload 'gtube-video-by-tag "gtube" "\
-Retrieve content having specified tag.
-optional args page and count specify position in result-set and
-  number of results to retrieve.
-
-\(fn TAG &optional PAGE COUNT)" t nil)
-
-(autoload 'gtube-video-by-category-and-tag "gtube" "\
-Retrieve content from specified category having specified tag.
-optional args page and count specify position in result-set and
-  number of results to retrieve.
-
-\(fn CATEGORY TAG &optional PAGE COUNT)" t nil)
-
-(autoload 'gtube-video-playlist "gtube" "\
-Retrieve content in specified playlist.
-optional args page and count specify position in result-set and
-  number of results to retrieve.
-
-\(fn PLAYLIST-ID &optional PAGE COUNT)" t nil)
-
-(autoload 'gtube-video-popular "gtube" "\
-Retrieve popular content for specified time-range.
-  Time-range is one of day, week, month, or all.
-
-\(fn TIME-RANGE)" t nil)
-
-(autoload 'gtube-video-by-user "gtube" "\
-Retrieve content from specified user.
-optional args page and count specify position in result-set and
-  number of results to retrieve.
-
-\(fn USER &optional PAGE COUNT)" t nil)
-
-(autoload 'gtube-video-featured "gtube" "\
-Retrieved featured video list.
-
-\(fn)" t nil)
-
-;;;***
-
-;;;### (autoloads nil "gweb" "gweb.el" (21318 51016 0 0))
+;;;### (autoloads nil "gweb" "gweb.el" (22017 62260 591224 82000))
 ;;; Generated autoloads from gweb.el
 
 (defsubst gweb-google-autocomplete-with-corpus (corpus) "\
 Read user input using Google Suggest for auto-completion.
-Uses specified corpus for prompting and suggest selection." (let* ((completer (intern (format "gweb-%s-suggest-completer" corpus))) (minibuffer-completing-file-name t) (completion-ignore-case t) (word (thing-at-point (quote word))) (query nil)) (unless (fboundp completer) (error "No  suggest handler for corpus %s" corpus)) (setq query (completing-read corpus completer nil nil word (quote gweb-history))) (pushnew query gweb-history) (g-url-encode query)))
+Uses specified corpus for prompting and suggest selection." (let* ((completer (intern (format "gweb-%s-suggest-completer" corpus))) (minibuffer-completing-file-name t) (completion-ignore-case t) (word (thing-at-point (quote word))) (query nil)) (unless (fboundp completer) (error "No  suggest handler for corpus %s" corpus)) (setq query (completing-read (format "%s: " corpus) completer nil nil word (quote gweb-history))) (pushnew query gweb-history) (g-url-encode query)))
 
 (autoload 'gweb-google-at-point "gweb" "\
 Google for term at point, and display top result succinctly.
@@ -484,12 +298,12 @@ Optional interactive prefix arg refresh forces this cached URL to be refreshed.
 ;;;***
 
 ;;;### (autoloads nil nil ("g-autogen.el" "g-cus-load.el" "g-load-path.el"
-;;;;;;  "g-utils.el" "g.el" "gf.el" "gnotebook.el" "gwis.el" "indent-files.el"
-;;;;;;  "org2blogger.el") (21621 12299 657489 444000))
+;;;;;;  "g-utils.el" "g.el" "gf.el" "indent-files.el" "org2blogger.el")
+;;;;;;  (22093 9712 952743 200000))
 
 ;;;***
 
-;;;### (autoloads nil "g-app" "g-app.el" (21527 34501 547871 161000))
+;;;### (autoloads nil "g-app" "g-app.el" (21857 972 0 0))
 ;;; Generated autoloads from g-app.el
 
 (autoload 'g-app-publish "g-app" "\
