@@ -1,5 +1,5 @@
 ;;; gweb.el --- Google Search
-;;;$Id: gweb.el 9016 2014-04-09 01:03:10Z tv.raman.tv $
+;;;$Id$
 ;;; $Author: raman $
 ;;; Description:  AJAX Search -> Lisp
 ;;; Keywords: Google   AJAX API
@@ -45,13 +45,13 @@
 
 ;;}}}
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;;; Commentary:
-;;{{{  introduction
 
+;;{{{  introduction
+;;; Commentary:
 ;;; Provide Google services --- such as search, search-based completion etc.
 ;;; For use from within Emacs tools.
 ;;; This is meant to be fast and efficient --- and uses WebAPIs as opposed to HTML  scraping.
-
+;;; Code:
 ;;}}}
 ;;{{{  Required modules
 
@@ -91,28 +91,27 @@
 ;;; Get search completions from Google
 ;;; Service Names: (corpus)
 ;; youtube : 'youtube',
-;; 			books : 'books',
-;; 			products : 'products-cc',
-;; 			news : 'news-cc',
-;; 			img : 'img',
-;; 			web : 'psy'
+;;                      books : 'books',
+;;                      products : 'products-cc',
+;;                      news : 'news-cc',
+;;                      img : 'img',
+;;                      web : 'psy'
 ;; youtube: 'youtube
- 
+
 (defvar gweb-suggest-url
   "http://clients1.google.com/complete/search?json=t&nohtml=t&nolabels=t&client=%s&q=%s"
   "URL  that gets suggestions from Google as JSON.")
 ;;; corpus is ds=n for News
-;;; ds=r for recipes 
+;;; ds=r for recipes
 
 (defsubst gweb-suggest (input &optional corpus)
   "Get completion list from Google Suggest."
   (declare (special gweb-suggest-url))
   (unless (> (length input) 0) (setq input minibuffer-default))
+  (unless corpus (setq corpus "psy"))
   (g-using-scratch
    (let ((js nil)
-         (url
-          (format gweb-suggest-url (or corpus "psy")
-                  (g-url-encode input))))
+         (url (format gweb-suggest-url corpus (g-url-encode input))))
      (call-process
       g-curl-program
       nil t nil
@@ -124,69 +123,66 @@
            collect
            (replace-regexp-in-string
             "</?b>" ""
-            (aref e 0))))))
+            ;;; note: psy is different:
+            (if (string= corpus "psy")
+                (aref e 0)
+              e))))))
 
 (defvar gweb-google-suggest-metadata
   '(metadata .
              (
-              ; Google suggest returns suggestions already sorted 
+                                        ; Google suggest returns suggestions already sorted
               (display-sort-function . identity)
-              ; add annots function here
+                                        ; add annots function here
               ))
   "Metadata returned by google-suggest completer.")
 
 (defun gweb-suggest-completer (string predicate action)
   "Generate completions using Google Suggest. "
-  (save-current-buffer 
-    (set-buffer 
-     (let ((window (minibuffer-selected-window))) 
-       (if (window-live-p window) 
-           (window-buffer window) 
+  (save-current-buffer
+    (set-buffer
+     (let ((window (minibuffer-selected-window)))
+       (if (window-live-p window)
+           (window-buffer window)
          (current-buffer))))
     (cond
      ((eq action 'metadata) gweb-google-suggest-metadata)
      (t
-      (complete-with-action action 
+      (complete-with-action action
                             (gweb-suggest string)
                             string predicate)))))
 
-
 ;;{{{  Generate suggest handlers for Google properties
 (loop for c in
       '("news-cc" "products-cc" "youtube" "books" "img")
       do
       (eval
        `(defun
-          , (intern
-             (format  "gweb-%s-suggest-completer" c))
-          (string predicate action)
+            , (intern
+               (format  "gweb-%s-suggest-completer" c))
+            (string predicate action)
           ,(format
             "Generate completions using Google %s Suggest. " c)
-          (save-current-buffer 
-            (set-buffer 
-             (let ((window (minibuffer-selected-window))) 
-               (if (window-live-p window) 
-                   (window-buffer window) 
+          (save-current-buffer
+            (set-buffer
+             (let ((window (minibuffer-selected-window)))
+               (if (window-live-p window)
+                   (window-buffer window)
                  (current-buffer))))
             (cond
              ((eq action 'metadata) gweb-google-suggest-metadata)
              (t
-              (complete-with-action action 
+              (complete-with-action action
                                     (gweb-suggest string ,c)
                                     string predicate)))))))
 
 ;;}}}
 
-
-
-
-
 (defvar gweb-history nil
   "History of Google Search queries.")
 
 (put 'gweb-history 'history-length 100)
 
-
 ;;; Emacs 23 and beyond:
 ;;; i.e. if complete-with-action is defined
 
@@ -206,7 +202,6 @@
     (pushnew  query gweb-history)
     (g-url-encode query)))
 
-
 ;;;###autoload
 
 (defsubst gweb-google-autocomplete-with-corpus (corpus)
@@ -222,7 +217,7 @@ Uses specified corpus for prompting and suggest selection."
       (error "No  suggest handler for corpus %s" corpus))
     (setq query
           (completing-read
-           corpus
+           (format "%s: " corpus)
            completer                   ; collection
            nil nil                     ; predicate required-match
            word                        ; initial input
@@ -245,7 +240,7 @@ Uses specified corpus for prompting and suggest selection."
            word 'gweb-history))
     (pushnew  query gweb-history)
     (g-url-encode query)))
-  
+
 ;;}}}
 ;;{{{ Search Helpers
 
@@ -285,7 +280,7 @@ Uses specified corpus for prompting and suggest selection."
     (when results
       (concat
        (format "<html><title>News Results For %s</title><ol>" query)
-       (mapconcat 
+       (mapconcat
         #'(lambda (a)
             (format "<li><a href='%s'>%s</a>\n%s
 <a href='%s'>Related Stories</a></li>"
@@ -303,14 +298,14 @@ Uses specified corpus for prompting and suggest selection."
   (let ((html (gweb-news-html query)))
     (cond
      ((null html) (message "No news found."))
-     (t 
+     (t
       (g-using-scratch
        (insert html)
        (browse-url-of-buffer))))))
 ;;}}}
 ;;{{{ Interactive Commands:
 
-;;; Need to be smarter about guessing default term 
+;;; Need to be smarter about guessing default term
 ;;; thing-at-point can return an empty string,
 ;;; and this is not a good thing for Google Suggest which will error out.
 (defvar gweb-search-results-handler nil
@@ -332,7 +327,7 @@ Optional interactive prefix arg refresh forces this cached URL to be refreshed."
    ((and (not refresh)
          (get-text-property (point) 'lucky-url))
     (browse-url (get-text-property (point) 'lucky-url)))
-   (t 
+   (t
     (let* ((results (gweb-web-results  search-term))
            (lucky (aref results 0))
            (inhibit-read-only t)
@@ -344,7 +339,7 @@ Optional interactive prefix arg refresh forces this cached URL to be refreshed."
                      (format
                       "echo '%s' | lynx -dump -stdin 2>/dev/null"
                       (g-json-get 'content lucky)))))
-      (when bounds 
+      (when bounds
         (add-text-properties   (car bounds) (cdr bounds)
                                (list 'lucky-url url
                                      'face 'highlight)))
