@@ -1,5 +1,5 @@
 ;;; outloud-voices.el --- Define various device independent voices in terms of OutLoud tags
-;;; $Id: outloud-voices.el 8312 2013-05-01 16:03:33Z tv.raman.tv $
+;;; $Id$
 ;;; $Author: tv.raman.tv $
 ;;; Description:  Module to set up Eloquent voices and personalities
 ;;; Keywords: Voice, Personality, IBM ViaVoice Outloud
@@ -16,7 +16,7 @@
 ;;}}}
 ;;{{{  Copyright:
 
-;;;Copyright (C) 1995 -- 2011, T. V. Raman 
+;;;Copyright (C) 1995 -- 2015, T. V. Raman 
 ;;; All Rights Reserved.
 ;;;
 ;;; This file is not part of GNU Emacs, but the same permissions apply.
@@ -52,6 +52,7 @@
 (declaim  (optimize  (safety 0) (speed 3)))
 (require 'acss-structure)
 (require 'dtk-unicode)
+(require 'tts)
 
 ;;}}}
 ;;{{{ Forward declarations:
@@ -70,14 +71,12 @@
 (defun outloud ()
   "Select Outloud server."
   (interactive)
-  (dtk-select-server "outloud")
-  (dtk-initialize))
+  (funcall-interactively #'dtk-select-server "outloud"))
 
 (defun outloud-32()
   "Select 32-Outloud server."
   (interactive)
-  (dtk-select-server "32-outloud")
-  (dtk-initialize))
+  (funcall-interactively #'dtk-select-server "32-outloud"))
 
 ;;}}}
 ;;{{{  voice table
@@ -465,19 +464,16 @@ and TABLE gives the values along that dimension."
 (defun outloud-list-voices ()
   "List defined voices."
   (declare (special outloud-voice-table))
-  (loop for k being the hash-keys of outloud-voice-table 
-        collect   k))
+  (loop for k being the hash-keys of outloud-voice-table collect   k))
 
 ;;}}}
 ;;{{{ Configurater 
 ;;;###autoload
 (defun outloud-configure-tts ()
   "Configure TTS environment to use ViaVoice  family of synthesizers."
-  (declare (special tts-default-speech-rate
-                    tts-default-voice
+  (declare (special tts-default-speech-rate tts-default-voice
                     outloud-default-speech-rate
-                    dtk-speech-rate-step
-                    dtk-speech-rate-base
+                    dtk-speech-rate-step dtk-speech-rate-base
                     dtk-speaker-process))
   (fset 'tts-list-voices'outloud-list-voices)
   (fset 'tts-voice-defined-p 'outloud-voice-defined-p)
@@ -494,6 +490,24 @@ and TABLE gives the values along that dimension."
                 dtk-speech-rate-base 50)
   (dtk-unicode-update-untouched-charsets '(ascii latin-iso8859-1 latin-iso8859-15 latin-iso8859-9 eight-bit-graphic)))
 
+;;}}}
+;;{{{  tts-env for Outloud:
+
+;;;###autoload
+(defun outloud-make-tts-env  ()
+  "Constructs a TTS environment for Outloud."
+  (declare (special outloud-default-speech-rate))
+  (make-tts-env
+   :name :outloud :default-voice 'paul
+   :default-speech-rate outloud-default-speech-rate
+   :list-voices #'outloud-list-voices
+   :acss-voice-defined-p #'outloud-voice-defined-p
+   :get-acss-voice-command #'outloud-get-voice-command
+   :define-voice-from-acss #'outloud-define-voice-from-speech-style
+   :speech-rate-base 50 :speech-rate-step 10))
+
+(tts-env-set :outloud  (outloud-make-tts-env))
+
 ;;}}}
 (provide 'outloud-voices)
 ;;{{{  emacs local variables
